<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('booking_remind');

// 记录访问日志
record_log('访问预订提醒页面');

// 处理发送提醒操作
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'send_reminder') {
        $booking_id = isset($_POST['booking_id']) ? intval($_POST['booking_id']) : 0;
        $message = isset($_POST['message']) ? trim($_POST['message']) : '';
        $remind_type = isset($_POST['remind_type']) ? intval($_POST['remind_type']) : 1; // 1-短信, 2-邮件

        if ($booking_id <= 0) {
            $error = '无效的预订ID！';
        } elseif (empty($message)) {
            $error = '提醒内容不能为空！';
        } else {
            try {
                // 获取当前用户ID
                $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;

                // 获取预订信息用于记录
                $stmt = $pdo->prepare("SELECT booking_no, guest_name FROM booking_orders WHERE id = ?");
                $stmt->execute([$booking_id]);
                $booking = $stmt->fetch();

                // 提醒类型文本
                $remind_type_text = $remind_type == 1 ? '短信' : '邮件';

                // 使用sys_logs表记录提醒信息
                $operation = "发送预订提醒：预订号[{$booking['booking_no']}]，客人[{$booking['guest_name']}]，方式[{$remind_type_text}]，内容：{$message}";

                $stmt = $pdo->prepare("
                    INSERT INTO sys_logs (
                        user_id, username, operation, ip, create_time
                    ) VALUES (?, ?, ?, ?, NOW())
                ");

                $username = isset($_SESSION['username']) ? $_SESSION['username'] : 'system';
                $ip = $_SERVER['REMOTE_ADDR'];

                $result = $stmt->execute([$operator_id, $username, $operation, $ip]);

                if ($result) {
                    // 模拟发送提醒（实际项目中应该调用短信或邮件发送API）
                    $success = "提醒已成功发送！（模拟）";
                } else {
                    $error = '提醒发送失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取明天将到达的预订
try {
    $stmt = $pdo->prepare("
        SELECT b.id, b.booking_no, b.guest_name, b.guest_mobile, b.guest_email,
               b.arrival_date, b.departure_date, b.special_request, 
               c.channel_name, rt.type_name, b.room_count
        FROM booking_orders b
        LEFT JOIN booking_channels c ON b.channel_id = c.id
        LEFT JOIN room_types rt ON b.room_type_id = rt.id
        WHERE b.status = 2 
        AND b.arrival_date = DATE_ADD(CURDATE(), INTERVAL 1 DAY)
        ORDER BY b.create_time DESC
    ");

    $stmt->execute();
    $tomorrow_arrivals = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取明日到达预订失败：' . $e->getMessage();
    $tomorrow_arrivals = [];
}

// 获取今天将到达的预订
try {
    $stmt = $pdo->prepare("
        SELECT b.id, b.booking_no, b.guest_name, b.guest_mobile, b.guest_email,
               b.arrival_date, b.departure_date, b.special_request, 
               c.channel_name, rt.type_name, b.room_count
        FROM booking_orders b
        LEFT JOIN booking_channels c ON b.channel_id = c.id
        LEFT JOIN room_types rt ON b.room_type_id = rt.id
        WHERE b.status = 2 
        AND b.arrival_date = CURDATE()
        ORDER BY b.create_time DESC
    ");

    $stmt->execute();
    $today_arrivals = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取今日到达预订失败：' . $e->getMessage();
    $today_arrivals = [];
}

// 获取最近的提醒记录（从sys_logs表中获取）
try {
    $stmt = $pdo->query("
        SELECT l.id, l.user_id as operator_id, l.username as operator_name, 
               l.operation as message, l.create_time
        FROM sys_logs l
        WHERE l.operation LIKE '发送预订提醒%'
        ORDER BY l.create_time DESC
        LIMIT 20
    ");

    $remind_logs = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取提醒记录失败：' . $e->getMessage();
    $remind_logs = [];
}

// 判断是否显示发送提醒表单
$send_reminder = null;
if (isset($_GET['send']) && intval($_GET['send']) > 0) {
    $booking_id = intval($_GET['send']);
    try {
        $stmt = $pdo->prepare("
            SELECT b.id, b.booking_no, b.guest_name, b.guest_mobile, b.guest_email,
                   b.arrival_date, b.departure_date, b.room_count, 
                   rt.type_name
            FROM booking_orders b
            LEFT JOIN room_types rt ON b.room_type_id = rt.id
            WHERE b.id = ?
        ");
        $stmt->execute([$booking_id]);
        $send_reminder = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取预订详情失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>预订提醒</h2>
            <div class="breadcrumb">
                <a href="index.php">预订管理</a> &gt; 预订提醒
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($send_reminder): ?>
                <!-- 发送提醒表单 -->
                <h3>发送预订提醒 - <?php echo $send_reminder['booking_no']; ?></h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="send_reminder">
                        <input type="hidden" name="booking_id" value="<?php echo $send_reminder['id']; ?>">

                        <div class="booking-details">
                            <p><strong>预订编号：</strong> <?php echo $send_reminder['booking_no']; ?></p>
                            <p><strong>客人姓名：</strong> <?php echo $send_reminder['guest_name']; ?></p>
                            <p><strong>联系电话：</strong> <?php echo $send_reminder['guest_mobile']; ?></p>
                            <p><strong>电子邮箱：</strong> <?php echo $send_reminder['guest_email'] ?: '无'; ?></p>
                            <p><strong>入住日期：</strong> <?php echo $send_reminder['arrival_date']; ?></p>
                            <p><strong>离店日期：</strong> <?php echo $send_reminder['departure_date']; ?></p>
                            <p><strong>房型房数：</strong> <?php echo $send_reminder['type_name']; ?> (<?php echo $send_reminder['room_count']; ?>间)</p>
                        </div>

                        <div class="form-group">
                            <label for="remind_type">提醒方式：</label>
                            <select id="remind_type" name="remind_type" required>
                                <option value="1" <?php echo empty($send_reminder['guest_mobile']) ? 'disabled' : ''; ?>>短信提醒</option>
                                <option value="2" <?php echo empty($send_reminder['guest_email']) ? 'disabled' : ''; ?>>邮件提醒</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="message">提醒内容：</label>
                            <textarea id="message" name="message" rows="5" required></textarea>
                            <p class="form-hint">可以使用变量：{姓名}、{订单号}、{入住日期}、{离店日期}、{房型}、{房间数}</p>
                        </div>

                        <div class="form-group">
                            <label>快速模板：</label>
                            <div class="template-buttons">
                                <button type="button" id="template-arrival" class="btn btn-sm btn-secondary">入住提醒</button>
                                <button type="button" id="template-prepay" class="btn btn-sm btn-secondary">预付提醒</button>
                                <button type="button" id="template-cancel" class="btn btn-sm btn-secondary">取消提醒</button>
                            </div>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">发送提醒</button>
                            <a href="remind.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <div class="remind-sections">
                <!-- 明日到达预订 -->
                <h3>明日到达预订 (<?php echo count($tomorrow_arrivals); ?>)</h3>
                <?php if (empty($tomorrow_arrivals)): ?>
                    <p>没有明日到达的预订。</p>
                <?php else: ?>
                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>预订编号</th>
                                    <th>客人姓名</th>
                                    <th>联系方式</th>
                                    <th>渠道</th>
                                    <th>入住日期</th>
                                    <th>离店日期</th>
                                    <th>房型</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($tomorrow_arrivals as $booking): ?>
                                    <tr>
                                        <td><?php echo $booking['booking_no']; ?></td>
                                        <td><?php echo $booking['guest_name']; ?></td>
                                        <td>
                                            <?php echo $booking['guest_mobile']; ?><br>
                                            <small><?php echo $booking['guest_email'] ?: '-'; ?></small>
                                        </td>
                                        <td><?php echo $booking['channel_name']; ?></td>
                                        <td><?php echo $booking['arrival_date']; ?></td>
                                        <td><?php echo $booking['departure_date']; ?></td>
                                        <td><?php echo $booking['type_name']; ?> (<?php echo $booking['room_count']; ?>间)</td>
                                        <td>
                                            <a href="remind.php?send=<?php echo $booking['id']; ?>" class="btn btn-sm btn-primary">发送提醒</a>
                                            <a href="order.php?view=<?php echo $booking['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <!-- 今日到达预订 -->
                <h3>今日到达预订 (<?php echo count($today_arrivals); ?>)</h3>
                <?php if (empty($today_arrivals)): ?>
                    <p>没有今日到达的预订。</p>
                <?php else: ?>
                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>预订编号</th>
                                    <th>客人姓名</th>
                                    <th>联系方式</th>
                                    <th>渠道</th>
                                    <th>入住日期</th>
                                    <th>离店日期</th>
                                    <th>房型</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($today_arrivals as $booking): ?>
                                    <tr>
                                        <td><?php echo $booking['booking_no']; ?></td>
                                        <td><?php echo $booking['guest_name']; ?></td>
                                        <td>
                                            <?php echo $booking['guest_mobile']; ?><br>
                                            <small><?php echo $booking['guest_email'] ?: '-'; ?></small>
                                        </td>
                                        <td><?php echo $booking['channel_name']; ?></td>
                                        <td><?php echo $booking['arrival_date']; ?></td>
                                        <td><?php echo $booking['departure_date']; ?></td>
                                        <td><?php echo $booking['type_name']; ?> (<?php echo $booking['room_count']; ?>间)</td>
                                        <td>
                                            <a href="remind.php?send=<?php echo $booking['id']; ?>" class="btn btn-sm btn-primary">发送提醒</a>
                                            <a href="order.php?view=<?php echo $booking['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <!-- 提醒记录 -->
                <h3>提醒记录</h3>
                <div class="data-list">
                    <?php if (empty($remind_logs)): ?>
                        <p>暂无提醒记录。</p>
                    <?php else: ?>
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>操作时间</th>
                                    <th>操作人</th>
                                    <th>提醒内容</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($remind_logs as $log): ?>
                                    <tr>
                                        <td><?php echo date('Y-m-d H:i', strtotime($log['create_time'])); ?></td>
                                        <td><?php echo $log['operator_name']; ?></td>
                                        <td><?php echo $log['message']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <script type="text/javascript">
        document.addEventListener('DOMContentLoaded', function() {
            // 提醒模板快速填充
            const templateArrival = document.getElementById('template-arrival');
            const templatePrepay = document.getElementById('template-prepay');
            const templateCancel = document.getElementById('template-cancel');
            const messageField = document.getElementById('message');

            if (templateArrival && messageField) {
                templateArrival.addEventListener('click', function() {
                    const guestName = "<?php echo $send_reminder ? $send_reminder['guest_name'] : ''; ?>";
                    const arrivalDate = "<?php echo $send_reminder ? $send_reminder['arrival_date'] : ''; ?>";
                    const roomType = "<?php echo $send_reminder ? $send_reminder['type_name'] : ''; ?>";
                    const roomCount = "<?php echo $send_reminder ? $send_reminder['room_count'] : ''; ?>";
                    const bookingNo = "<?php echo $send_reminder ? $send_reminder['booking_no'] : ''; ?>";

                    messageField.value = `尊敬的${guestName}您好，感谢您选择我们酒店！您预订的${arrivalDate}入住的${roomCount}间${roomType}已确认，预订单号：${bookingNo}。期待您的光临，如有任何问题，请随时联系我们：0755-12345678。`;
                });
            }

            if (templatePrepay && messageField) {
                templatePrepay.addEventListener('click', function() {
                    const guestName = "<?php echo $send_reminder ? $send_reminder['guest_name'] : ''; ?>";
                    const arrivalDate = "<?php echo $send_reminder ? $send_reminder['arrival_date'] : ''; ?>";
                    const bookingNo = "<?php echo $send_reminder ? $send_reminder['booking_no'] : ''; ?>";

                    messageField.value = `尊敬的${guestName}您好，您预订的${arrivalDate}入住的房间（单号：${bookingNo}）需要提前预付订金以确保预订。请在12小时内完成支付，否则预订可能会被取消。如有疑问，请联系：0755-12345678。`;
                });
            }

            if (templateCancel && messageField) {
                templateCancel.addEventListener('click', function() {
                    const guestName = "<?php echo $send_reminder ? $send_reminder['guest_name'] : ''; ?>";
                    const bookingNo = "<?php echo $send_reminder ? $send_reminder['booking_no'] : ''; ?>";

                    messageField.value = `尊敬的${guestName}您好，很遗憾地通知您，您的预订（单号：${bookingNo}）因系统原因需要取消。我们对此深表歉意，并将为您提供后续预订的优惠。如有任何疑问，请联系我们：0755-12345678。`;
                });
            }
        });
    </script>
</body>

</html>