<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_refund');

// 记录访问日志
record_log('访问退款管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 申请退款
    if ($_POST['action'] == 'apply') {
        $refund_no = 'REF' . date('YmdHis') . rand(100, 999); // 生成退款单号
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1; // 1-退房退款，2-取消预订退款
        $booking_id = isset($_POST['booking_id']) && $_POST['booking_id'] > 0 ? intval($_POST['booking_id']) : null;
        $checkin_id = isset($_POST['checkin_id']) && $_POST['checkin_id'] > 0 ? intval($_POST['checkin_id']) : null;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $refund_reason = isset($_POST['refund_reason']) ? trim($_POST['refund_reason']) : '';
        $payment_method = isset($_POST['payment_method']) ? intval($_POST['payment_method']) : 1;

        if ($amount <= 0) {
            $error = '退款金额必须大于0！';
        } elseif (!$booking_id && !$checkin_id) {
            $error = '请关联预订单或入住单！';
        } else {
            try {
                $pdo->beginTransaction();

                // 创建支付记录（作为退款记录）
                $stmt = $pdo->prepare("
                    INSERT INTO finance_payments (
                        payment_no, type, booking_id, checkin_id, amount, payment_method, 
                        payment_time, status, operator_id, remark
                    ) VALUES (?, 2, ?, ?, ?, ?, NOW(), 0, ?, ?)
                ");
                $result = $stmt->execute([
                    $refund_no,
                    $booking_id,
                    $checkin_id,
                    $amount,
                    $payment_method,
                    $_SESSION['user_id'], // 当前登录用户ID
                    $refund_reason
                ]);

                if ($result) {
                    // 如果有关联的订单，更新订单状态
                    if ($booking_id) {
                        $stmt = $pdo->prepare("UPDATE booking_orders SET status = 4 WHERE id = ?");
                        $stmt->execute([$booking_id]);
                    }

                    $pdo->commit();
                    record_log("申请退款：{$refund_no}，金额：{$amount}，原因：{$refund_reason}");
                    $success = '退款申请提交成功，等待审核！';
                } else {
                    $pdo->rollBack();
                    $error = '退款申请提交失败！';
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 审核退款
    elseif ($_POST['action'] == 'approve') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;
        $audit_remark = isset($_POST['audit_remark']) ? trim($_POST['audit_remark']) : '';

        if ($payment_id <= 0) {
            $error = '无效的退款ID！';
        } else {
            try {
                $pdo->beginTransaction();

                // 获取退款信息
                $stmt = $pdo->prepare("
                    SELECT payment_no, booking_id, checkin_id, amount 
                    FROM finance_payments 
                    WHERE id = ? AND type = 2 AND status = 0
                ");
                $stmt->execute([$payment_id]);
                $refund = $stmt->fetch();

                if (!$refund) {
                    $error = '退款申请不存在或已处理！';
                    $pdo->rollBack();
                } else {
                    // 更新退款状态为已退款
                    $stmt = $pdo->prepare("
                        UPDATE finance_payments 
                        SET status = 2, 
                            payment_time = NOW(), 
                            remark = CONCAT(remark, '；审核备注：', ?) 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([$audit_remark, $payment_id]);

                    if ($result) {
                        $pdo->commit();
                        record_log("审核通过退款：{$refund['payment_no']}，金额：{$refund['amount']}");
                        $success = '退款审核通过，已完成退款！';
                    } else {
                        $pdo->rollBack();
                        $error = '退款审核失败！';
                    }
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 拒绝退款
    elseif ($_POST['action'] == 'reject') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;
        $reject_reason = isset($_POST['reject_reason']) ? trim($_POST['reject_reason']) : '';

        if ($payment_id <= 0) {
            $error = '无效的退款ID！';
        } elseif (empty($reject_reason)) {
            $error = '请填写拒绝原因！';
        } else {
            try {
                $pdo->beginTransaction();

                // 获取退款信息
                $stmt = $pdo->prepare("
                    SELECT payment_no, booking_id 
                    FROM finance_payments 
                    WHERE id = ? AND type = 2 AND status = 0
                ");
                $stmt->execute([$payment_id]);
                $refund = $stmt->fetch();

                if (!$refund) {
                    $error = '退款申请不存在或已处理！';
                    $pdo->rollBack();
                } else {
                    // 更新退款状态为已拒绝
                    $stmt = $pdo->prepare("
                        UPDATE finance_payments 
                        SET status = 3, 
                            remark = CONCAT(remark, '；拒绝原因：', ?) 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([$reject_reason, $payment_id]);

                    // 如果有关联的订单，恢复订单状态
                    if ($refund['booking_id']) {
                        $stmt = $pdo->prepare("UPDATE booking_orders SET status = 1 WHERE id = ? AND status = 4");
                        $stmt->execute([$refund['booking_id']]);
                    }

                    if ($result) {
                        $pdo->commit();
                        record_log("拒绝退款：{$refund['payment_no']}，原因：{$reject_reason}");
                        $success = '已拒绝退款申请！';
                    } else {
                        $pdo->rollBack();
                        $error = '拒绝退款操作失败！';
                    }
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除退款申请
    elseif ($_POST['action'] == 'delete') {
        $payment_id = isset($_POST['payment_id']) ? intval($_POST['payment_id']) : 0;

        if ($payment_id <= 0) {
            $error = '无效的退款ID！';
        } else {
            try {
                $pdo->beginTransaction();

                // 获取退款信息
                $stmt = $pdo->prepare("
                    SELECT payment_no, booking_id, status 
                    FROM finance_payments 
                    WHERE id = ? AND type = 2
                ");
                $stmt->execute([$payment_id]);
                $refund = $stmt->fetch();

                if (!$refund) {
                    $error = '退款申请不存在！';
                    $pdo->rollBack();
                } else {
                    // 已审核通过的退款不能删除
                    if ($refund['status'] == 2) {
                        $error = '已完成的退款不能删除！';
                        $pdo->rollBack();
                    } else {
                        // 删除退款记录
                        $stmt = $pdo->prepare("DELETE FROM finance_payments WHERE id = ?");
                        $result = $stmt->execute([$payment_id]);

                        // 如果有关联的订单且状态是申请退款中，恢复订单状态
                        if ($refund['booking_id'] && $refund['status'] == 0) {
                            $stmt = $pdo->prepare("UPDATE booking_orders SET status = 1 WHERE id = ? AND status = 4");
                            $stmt->execute([$refund['booking_id']]);
                        }

                        if ($result) {
                            $pdo->commit();
                            record_log("删除退款申请：{$refund['payment_no']}");
                            $success = '退款申请删除成功！';
                        } else {
                            $pdo->rollBack();
                            $error = '退款申请删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示申请退款表单
$show_apply_form = isset($_GET['show_form']) && $_GET['show_form'] == 'apply';

// 判断是否显示审核退款表单
$show_approve_form = false;
$refund_to_approve = null;
if (isset($_GET['approve']) && intval($_GET['approve']) > 0) {
    $payment_id = intval($_GET['approve']);
    try {
        $stmt = $pdo->prepare("
            SELECT p.*, 
                CASE 
                    WHEN p.booking_id IS NOT NULL THEN b.booking_no
                    WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                    ELSE NULL
                END AS order_no,
                CASE 
                    WHEN p.booking_id IS NOT NULL THEN b.guest_name
                    WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                    ELSE NULL
                END AS guest_name
            FROM finance_payments p
            LEFT JOIN booking_orders b ON p.booking_id = b.id
            LEFT JOIN checkin_orders c ON p.checkin_id = c.id
            WHERE p.id = ? AND p.type = 2 AND p.status = 0
        ");
        $stmt->execute([$payment_id]);
        $refund_to_approve = $stmt->fetch();
        if ($refund_to_approve) {
            $show_approve_form = true;
        }
    } catch (PDOException $e) {
        $error = '获取退款申请详情失败：' . $e->getMessage();
    }
}

// 判断是否显示拒绝退款表单
$show_reject_form = false;
$refund_to_reject = null;
if (isset($_GET['reject']) && intval($_GET['reject']) > 0) {
    $payment_id = intval($_GET['reject']);
    try {
        $stmt = $pdo->prepare("
            SELECT p.*, 
                CASE 
                    WHEN p.booking_id IS NOT NULL THEN b.booking_no
                    WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                    ELSE NULL
                END AS order_no,
                CASE 
                    WHEN p.booking_id IS NOT NULL THEN b.guest_name
                    WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                    ELSE NULL
                END AS guest_name
            FROM finance_payments p
            LEFT JOIN booking_orders b ON p.booking_id = b.id
            LEFT JOIN checkin_orders c ON p.checkin_id = c.id
            WHERE p.id = ? AND p.type = 2 AND p.status = 0
        ");
        $stmt->execute([$payment_id]);
        $refund_to_reject = $stmt->fetch();
        if ($refund_to_reject) {
            $show_reject_form = true;
        }
    } catch (PDOException $e) {
        $error = '获取退款申请详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_refund_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取预订单列表（用于关联选择）
try {
    $stmt = $pdo->query("
        SELECT b.id, b.booking_no, b.guest_name, b.total_amount, p.amount as paid_amount
        FROM booking_orders b
        LEFT JOIN (
            SELECT booking_id, SUM(amount) as amount 
            FROM finance_payments 
            WHERE type = 1 AND status = 1
            GROUP BY booking_id
        ) p ON b.id = p.booking_id
        WHERE b.status NOT IN (3, 5) 
        ORDER BY b.id DESC
    ");
    $bookings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预订单列表失败：' . $e->getMessage();
    $bookings = [];
}

// 获取入住单列表（用于关联选择）
try {
    $stmt = $pdo->query("
        SELECT c.id, c.checkin_no, c.guest_name, c.total_amount, p.amount as paid_amount
        FROM checkin_orders c
        LEFT JOIN (
            SELECT checkin_id, SUM(amount) as amount 
            FROM finance_payments 
            WHERE type = 1 AND status = 1
            GROUP BY checkin_id
        ) p ON c.id = p.checkin_id
        WHERE c.status != 3 
        ORDER BY c.id DESC
    ");
    $checkins = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取入住单列表失败：' . $e->getMessage();
    $checkins = [];
}

// 获取关联订单的支付记录列表
$original_payments = [];
if (isset($_GET['get_payments'])) {
    $order_type = isset($_GET['order_type']) ? $_GET['order_type'] : '';
    $order_id = isset($_GET['order_id']) ? intval($_GET['order_id']) : 0;

    if ($order_id > 0) {
        try {
            if ($order_type == 'booking') {
                $stmt = $pdo->prepare("
                    SELECT id, payment_no, amount, payment_method, payment_time 
                    FROM finance_payments 
                    WHERE booking_id = ? AND type = 1 AND status = 1
                    ORDER BY payment_time DESC
                ");
                $stmt->execute([$order_id]);
            } else {
                $stmt = $pdo->prepare("
                    SELECT id, payment_no, amount, payment_method, payment_time 
                    FROM finance_payments 
                    WHERE checkin_id = ? AND type = 1 AND status = 1
                    ORDER BY payment_time DESC
                ");
                $stmt->execute([$order_id]);
            }
            $original_payments = $stmt->fetchAll();
        } catch (PDOException $e) {
            $error = '获取支付记录失败：' . $e->getMessage();
        }
    }
}

// 获取筛选条件
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : -1;
$filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 构建查询条件
$where_clauses = ["p.type = 2 AND p.payment_time BETWEEN ? AND ?"];
$params = [$filter_start_date . ' 00:00:00', $filter_end_date . ' 23:59:59'];

if ($filter_status >= 0) {
    $where_clauses[] = "p.status = ?";
    $params[] = $filter_status;
}

$where_sql = implode(" AND ", $where_clauses);

// 获取所有退款记录
try {
    $stmt = $pdo->prepare("
        SELECT p.*, 
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.booking_no
                   WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                   ELSE NULL
               END AS order_no,
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.guest_name
                   WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                   ELSE NULL
               END AS guest_name,
               u.username as operator_name
        FROM finance_payments p
        LEFT JOIN booking_orders b ON p.booking_id = b.id
        LEFT JOIN checkin_orders c ON p.checkin_id = c.id
        LEFT JOIN sys_users u ON p.operator_id = u.id
        WHERE {$where_sql}
        ORDER BY p.payment_time DESC
    ");
    $stmt->execute($params);
    $refunds = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取退款列表失败：' . $e->getMessage();
    $refunds = [];
}

// 计算统计数据
$total_refund_amount = 0;
$pending_refund_amount = 0;
$completed_refund_amount = 0;

foreach ($refunds as $refund) {
    if ($refund['status'] == 0) {
        $pending_refund_amount += $refund['amount'];
    } elseif ($refund['status'] == 2) {
        $completed_refund_amount += $refund['amount'];
    }

    if ($refund['status'] != 3) { // 不包括被拒绝的
        $total_refund_amount += $refund['amount'];
    }
}

// 支付方式列表
$payment_methods = [
    1 => '现金',
    2 => '信用卡',
    3 => '微信',
    4 => '支付宝',
    5 => '银行转账'
];

// 退款原因列表
$refund_reasons = [
    1 => '客户取消预订',
    2 => '提前退房',
    3 => '订单变更',
    4 => '服务问题',
    5 => '系统错误',
    6 => '其他原因'
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>退款管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>退款管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 退款管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_apply_form && !$show_approve_form && !$show_reject_form): ?>
                    <a href="refund.php?show_form=apply" class="btn btn-primary">申请退款</a>
                <?php endif; ?>
            </div>

            <?php if ($show_apply_form): ?>
                <!-- 申请退款表单 -->
                <h3>申请退款</h3>
                <div class="form-container">
                    <form method="post" action="" id="refundForm">
                        <input type="hidden" name="action" value="apply">

                        <div class="form-group">
                            <label for="type">退款类型：</label>
                            <select id="type" name="type" required>
                                <option value="1">退房退款</option>
                                <option value="2">取消预订退款</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="booking_id">关联预订单：</label>
                            <select id="booking_id" name="booking_id" onchange="getPaymentRecords('booking', this.value)">
                                <option value="0">不关联预订单</option>
                                <?php foreach ($bookings as $booking): ?>
                                    <option value="<?php echo $booking['id']; ?>"
                                        data-amount="<?php echo $booking['paid_amount'] ?: 0; ?>">
                                        <?php echo $booking['booking_no']; ?> - <?php echo $booking['guest_name']; ?>
                                        (已付: ￥<?php echo number_format($booking['paid_amount'] ?: 0, 2); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="checkin_id">关联入住单：</label>
                            <select id="checkin_id" name="checkin_id" onchange="getPaymentRecords('checkin', this.value)">
                                <option value="0">不关联入住单</option>
                                <?php foreach ($checkins as $checkin): ?>
                                    <option value="<?php echo $checkin['id']; ?>"
                                        data-amount="<?php echo $checkin['paid_amount'] ?: 0; ?>">
                                        <?php echo $checkin['checkin_no']; ?> - <?php echo $checkin['guest_name']; ?>
                                        (已付: ￥<?php echo number_format($checkin['paid_amount'] ?: 0, 2); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group" id="payment_records_container" style="display:none;">
                            <label>关联支付记录：</label>
                            <div id="payment_records"></div>
                        </div>

                        <div class="form-group">
                            <label for="amount">退款金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0.01" required>
                            <p class="form-hint">退款金额不能超过已付金额</p>
                        </div>

                        <div class="form-group">
                            <label for="refund_reason_select">退款原因：</label>
                            <select id="refund_reason_select" onchange="updateRefundReason()">
                                <option value="">请选择退款原因</option>
                                <?php foreach ($refund_reasons as $key => $reason): ?>
                                    <option value="<?php echo $reason; ?>"><?php echo $reason; ?></option>
                                <?php endforeach; ?>
                                <option value="custom">自定义原因</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="refund_reason">详细原因：</label>
                            <textarea id="refund_reason" name="refund_reason" rows="3" required></textarea>
                        </div>

                        <div class="form-group">
                            <label for="payment_method">退款方式：</label>
                            <select id="payment_method" name="payment_method" required>
                                <?php foreach ($payment_methods as $key => $method): ?>
                                    <option value="<?php echo $key; ?>"><?php echo $method; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">提交退款申请</button>
                            <a href="refund.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_approve_form): ?>
                <!-- 审核退款表单 -->
                <h3>审核退款申请</h3>
                <div class="form-container">
                    <div class="refund-info">
                        <p><strong>退款单号：</strong> <?php echo $refund_to_approve['payment_no']; ?></p>
                        <p><strong>关联订单：</strong> <?php echo $refund_to_approve['order_no'] ?: '-'; ?></p>
                        <p><strong>客人姓名：</strong> <?php echo $refund_to_approve['guest_name'] ?: '-'; ?></p>
                        <p><strong>退款金额：</strong> ￥<?php echo number_format($refund_to_approve['amount'], 2); ?></p>
                        <p><strong>申请原因：</strong> <?php echo $refund_to_approve['remark']; ?></p>
                        <p><strong>申请时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($refund_to_approve['create_time'])); ?></p>
                    </div>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="approve">
                        <input type="hidden" name="payment_id" value="<?php echo $refund_to_approve['id']; ?>">

                        <div class="form-group">
                            <label for="audit_remark">审核备注：</label>
                            <textarea id="audit_remark" name="audit_remark" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">通过退款</button>
                            <a href="refund.php?reject=<?php echo $refund_to_approve['id']; ?>" class="btn btn-danger">拒绝退款</a>
                            <a href="refund.php" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_reject_form): ?>
                <!-- 拒绝退款表单 -->
                <h3>拒绝退款申请</h3>
                <div class="form-container">
                    <div class="refund-info">
                        <p><strong>退款单号：</strong> <?php echo $refund_to_reject['payment_no']; ?></p>
                        <p><strong>关联订单：</strong> <?php echo $refund_to_reject['order_no'] ?: '-'; ?></p>
                        <p><strong>客人姓名：</strong> <?php echo $refund_to_reject['guest_name'] ?: '-'; ?></p>
                        <p><strong>退款金额：</strong> ￥<?php echo number_format($refund_to_reject['amount'], 2); ?></p>
                        <p><strong>申请原因：</strong> <?php echo $refund_to_reject['remark']; ?></p>
                        <p><strong>申请时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($refund_to_reject['create_time'])); ?></p>
                    </div>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="reject">
                        <input type="hidden" name="payment_id" value="<?php echo $refund_to_reject['id']; ?>">

                        <div class="form-group">
                            <label for="reject_reason">拒绝原因：</label>
                            <textarea id="reject_reason" name="reject_reason" rows="3" required></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-danger">确认拒绝</button>
                            <a href="refund.php" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_apply_form && !$show_approve_form && !$show_reject_form): ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="status">退款状态：</label>
                                <select id="status" name="status">
                                    <option value="-1">全部状态</option>
                                    <option value="0" <?php echo $filter_status === 0 ? 'selected' : ''; ?>>待审核</option>
                                    <option value="2" <?php echo $filter_status === 2 ? 'selected' : ''; ?>>已退款</option>
                                    <option value="3" <?php echo $filter_status === 3 ? 'selected' : ''; ?>>已拒绝</option>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="refund.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计信息 -->
                <div class="summary-box">
                    <div class="summary-item">
                        <span class="summary-label">总退款金额：</span>
                        <span class="summary-value">￥<?php echo number_format($total_refund_amount, 2); ?></span>
                    </div>
                    <div class="summary-item">
                        <span class="summary-label">待审核金额：</span>
                        <span class="summary-value">￥<?php echo number_format($pending_refund_amount, 2); ?></span>
                    </div>
                    <div class="summary-item">
                        <span class="summary-label">已退款金额：</span>
                        <span class="summary-value">￥<?php echo number_format($completed_refund_amount, 2); ?></span>
                    </div>
                </div>

                <!-- 退款列表 -->
                <h3>退款申请列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>退款单号</th>
                                <th>关联订单</th>
                                <th>客人</th>
                                <th>金额(元)</th>
                                <th>退款方式</th>
                                <th>申请时间</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($refunds as $refund): ?>
                                <tr>
                                    <td><?php echo $refund['payment_no']; ?></td>
                                    <td><?php echo $refund['order_no'] ?: '-'; ?></td>
                                    <td><?php echo $refund['guest_name'] ?: '-'; ?></td>
                                    <td><?php echo number_format($refund['amount'], 2); ?></td>
                                    <td><?php echo isset($payment_methods[$refund['payment_method']]) ? $payment_methods[$refund['payment_method']] : '未知'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($refund['payment_time'])); ?></td>
                                    <td>
                                        <?php
                                        switch ($refund['status']) {
                                            case 0:
                                                echo '<span class="status-warning">待审核</span>';
                                                break;
                                            case 2:
                                                echo '<span class="status-active">已退款</span>';
                                                break;
                                            case 3:
                                                echo '<span class="status-inactive">已拒绝</span>';
                                                break;
                                            default:
                                                echo '<span>未知</span>';
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <a href="refund.php?view=<?php echo $refund['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        <?php if ($refund['status'] == 0): ?>
                                            <a href="refund.php?approve=<?php echo $refund['id']; ?>" class="btn btn-sm btn-success">审核</a>
                                            <a href="refund.php?reject=<?php echo $refund['id']; ?>" class="btn btn-sm btn-warning">拒绝</a>
                                        <?php endif; ?>

                                        <?php if ($refund['status'] != 2): // 已退款的不能删除 
                                        ?>
                                            <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此退款申请吗？此操作不可恢复！');">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="payment_id" value="<?php echo $refund['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <?php if ($view_refund_id == $refund['id']): ?>
                                    <tr>
                                        <td colspan="8" class="details-row">
                                            <div class="refund-details">
                                                <div class="detail-group">
                                                    <h4>基本信息</h4>
                                                    <p><strong>退款单号：</strong> <?php echo $refund['payment_no']; ?></p>
                                                    <p><strong>金额：</strong> ￥<?php echo number_format($refund['amount'], 2); ?></p>
                                                    <p><strong>退款方式：</strong> <?php echo isset($payment_methods[$refund['payment_method']]) ? $payment_methods[$refund['payment_method']] : '未知'; ?></p>
                                                    <p><strong>申请时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($refund['create_time'])); ?></p>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>