<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory');

// 记录访问日志
record_log('访问物资库存页面');

// 初始化变量
$error = '';
$success = '';

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 库存入库
    if ($_POST['action'] == 'inbound') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

        if ($item_id <= 0) {
            $error = '请选择入库物资！';
        } elseif ($quantity <= 0) {
            $error = '入库数量必须大于0！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 检查物资是否存在
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM inv_items WHERE id = ? AND status = 1");
                $stmt->execute([$item_id]);
                if ($stmt->fetchColumn() == 0) {
                    throw new Exception('选择的物资不存在或已禁用！');
                }

                // 检查供应商是否存在
                if ($supplier_id > 0) {
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM inv_suppliers WHERE id = ? AND status = 1");
                    $stmt->execute([$supplier_id]);
                    if ($stmt->fetchColumn() == 0) {
                        throw new Exception('选择的供应商不存在或已禁用！');
                    }
                }

                // 更新或创建库存记录
                $stmt = $pdo->prepare("SELECT quantity FROM inv_stock WHERE item_id = ?");
                $stmt->execute([$item_id]);
                $stock = $stmt->fetch();

                if ($stock) {
                    $stmt = $pdo->prepare("
                        UPDATE inv_stock 
                        SET quantity = quantity + ?, update_time = NOW() 
                        WHERE item_id = ?
                    ");
                    $stmt->execute([$quantity, $item_id]);
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO inv_stock (item_id, quantity, update_time) 
                        VALUES (?, ?, NOW())
                    ");
                    $stmt->execute([$item_id, $quantity]);
                }

                // 记录库存交易
                $stmt = $pdo->prepare("
                    INSERT INTO inv_transactions 
                    (item_id, transaction_type, quantity, supplier_id, operator_id, transaction_time, remarks) 
                    VALUES (?, 1, ?, ?, ?, NOW(), ?)
                ");
                $stmt->execute([
                    $item_id,
                    $quantity,
                    $supplier_id > 0 ? $supplier_id : null,
                    $_SESSION['user_id'] ?? null,
                    $remarks
                ]);

                // 提交事务
                $pdo->commit();

                record_log("物资入库：物资ID {$item_id}，数量 {$quantity}");
                $success = '物资入库成功！';
            } catch (Exception $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '物资入库失败：' . $e->getMessage();
            }
        }
    }

    // 库存出库
    elseif ($_POST['action'] == 'outbound') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $department = isset($_POST['department']) ? trim($_POST['department']) : '';
        $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

        if ($item_id <= 0) {
            $error = '请选择出库物资！';
        } elseif ($quantity <= 0) {
            $error = '出库数量必须大于0！';
        } elseif (empty($department)) {
            $error = '请输入领用部门！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 检查库存是否足够
                $stmt = $pdo->prepare("
                    SELECT s.quantity, i.item_name 
                    FROM inv_stock s 
                    JOIN inv_items i ON s.item_id = i.id 
                    WHERE s.item_id = ?
                ");
                $stmt->execute([$item_id]);
                $stock = $stmt->fetch();

                if (!$stock) {
                    throw new Exception('该物资尚无库存记录！');
                }

                if ($stock['quantity'] < $quantity) {
                    throw new Exception("物资【{$stock['item_name']}】库存不足！当前库存: {$stock['quantity']}");
                }

                // 更新库存
                $stmt = $pdo->prepare("
                    UPDATE inv_stock 
                    SET quantity = quantity - ?, update_time = NOW() 
                    WHERE item_id = ?
                ");
                $stmt->execute([$quantity, $item_id]);

                // 记录库存交易
                $stmt = $pdo->prepare("
                    INSERT INTO inv_transactions 
                    (item_id, transaction_type, quantity, department, operator_id, transaction_time, remarks) 
                    VALUES (?, 2, ?, ?, ?, NOW(), ?)
                ");
                $stmt->execute([
                    $item_id,
                    $quantity,
                    $department,
                    $_SESSION['user_id'] ?? null,
                    $remarks
                ]);

                // 提交事务
                $pdo->commit();

                record_log("物资出库：物资ID {$item_id}，数量 {$quantity}，领用部门 {$department}");
                $success = '物资出库成功！';
            } catch (Exception $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '物资出库失败：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示入库表单
$show_inbound_form = isset($_GET['form']) && $_GET['form'] == 'inbound';

// 判断是否显示出库表单
$show_outbound_form = isset($_GET['form']) && $_GET['form'] == 'outbound';

// 获取库存信息
try {
    $stmt = $pdo->query("
        SELECT s.*, i.item_name, i.item_code, i.unit, c.category_name,
            (SELECT transaction_time FROM inv_transactions 
             WHERE item_id = s.item_id 
             ORDER BY transaction_time DESC LIMIT 1) as last_transaction_time
        FROM inv_stock s
        JOIN inv_items i ON s.item_id = i.id
        JOIN inv_categories c ON i.category_id = c.id
        ORDER BY c.id, i.id
    ");
    $stocks = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存信息失败：' . $e->getMessage();
    $stocks = [];
}

// 获取所有物资
try {
    $stmt = $pdo->query("
        SELECT i.*, c.category_name 
        FROM inv_items i 
        JOIN inv_categories c ON i.category_id = c.id 
        WHERE i.status = 1 
        ORDER BY c.id, i.id
    ");
    $items = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取物资列表失败：' . $e->getMessage();
    $items = [];
}

// 获取所有供应商
try {
    $stmt = $pdo->query("
        SELECT id, supplier_name FROM inv_suppliers 
        WHERE status = 1 
        ORDER BY id
    ");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取供应商列表失败：' . $e->getMessage();
    $suppliers = [];
}

// 获取最近的库存交易记录
try {
    $stmt = $pdo->query("
        SELECT t.*, i.item_name, i.item_code, i.unit, s.supplier_name,
            u.username as operator_name
        FROM inv_transactions t
        JOIN inv_items i ON t.item_id = i.id
        LEFT JOIN inv_suppliers s ON t.supplier_id = s.id
        LEFT JOIN sys_users u ON t.operator_id = u.id
        ORDER BY t.transaction_time DESC
        LIMIT 100
    ");
    $transactions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取库存交易记录失败：' . $e->getMessage();
    $transactions = [];
}

// 支持从URL中获取成功消息
if (empty($success) && isset($_GET['success'])) {
    $success = $_GET['success'];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .stock-low {
            color: #dc3545;
            font-weight: bold;
        }

        .transaction-type-1 {
            color: #28a745;
            /* 入库 */
        }

        .transaction-type-2 {
            color: #dc3545;
            /* 出库 */
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>物资库存管理</h2>
            <div class="breadcrumb">
                <a href="index.php">物资与库存管理</a> &gt; 物资库存
            </div>
        </div>

        <div class="content">
            <?php if (!empty($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (!empty($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_inbound_form && !$show_outbound_form): ?>
                    <a href="stock.php?form=inbound" class="btn btn-primary">物资入库</a>
                    <a href="stock.php?form=outbound" class="btn btn-secondary">物资出库</a>
                <?php else: ?>
                    <a href="stock.php" class="btn btn-secondary">返回库存列表</a>
                <?php endif; ?>
            </div>

            <?php if ($show_inbound_form): ?>
                <!-- 物资入库表单 -->
                <h3>物资入库</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="inbound">

                        <div class="form-group">
                            <label for="item_id">选择物资：</label>
                            <select id="item_id" name="item_id" required>
                                <option value="">-- 请选择物资 --</option>
                                <?php foreach ($items as $item): ?>
                                    <option value="<?php echo $item['id']; ?>" data-unit="<?php echo $item['unit']; ?>">
                                        <?php echo $item['item_name']; ?> (<?php echo $item['category_name']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quantity">入库数量：</label>
                            <div style="display: flex; align-items: center;">
                                <input type="number" id="quantity" name="quantity" min="1" required style="width: 150px;">
                                <span id="unit_text" style="margin-left: 10px;"></span>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="supplier_id">供应商：</label>
                            <select id="supplier_id" name="supplier_id">
                                <option value="">-- 请选择供应商（可选） --</option>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?php echo $supplier['id']; ?>"><?php echo $supplier['supplier_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remarks">入库备注：</label>
                            <textarea id="remarks" name="remarks" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">确认入库</button>
                            <a href="stock.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_outbound_form): ?>
                <!-- 物资出库表单 -->
                <h3>物资出库</h3>
                <div class="form-container">
                    <form method="post" action="" id="outboundForm">
                        <input type="hidden" name="action" value="outbound">

                        <div class="form-group">
                            <label for="item_id">选择物资：</label>
                            <select id="item_id" name="item_id" required>
                                <option value="">-- 请选择物资 --</option>
                                <?php foreach ($items as $item): ?>
                                    <?php
                                    // 查找该物资的库存
                                    $current_stock = 0;
                                    foreach ($stocks as $stock) {
                                        if ($stock['item_id'] == $item['id']) {
                                            $current_stock = $stock['quantity'];
                                            break;
                                        }
                                    }
                                    ?>
                                    <option value="<?php echo $item['id']; ?>"
                                        data-unit="<?php echo $item['unit']; ?>"
                                        data-stock="<?php echo $current_stock; ?>">
                                        <?php echo $item['item_name']; ?> (<?php echo $item['category_name']; ?>) - 库存: <?php echo $current_stock; ?> <?php echo $item['unit']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quantity">出库数量：</label>
                            <div style="display: flex; align-items: center;">
                                <input type="number" id="quantity" name="quantity" min="1" required style="width: 150px;">
                                <span id="unit_text" style="margin-left: 10px;"></span>
                                <span id="stock_warning" style="margin-left: 10px; color: #dc3545; display: none;">超出库存量！</span>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="department">领用部门：</label>
                            <input type="text" id="department" name="department" required>
                        </div>

                        <div class="form-group">
                            <label for="remarks">出库备注：</label>
                            <textarea id="remarks" name="remarks" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary" id="submitBtn">确认出库</button>
                            <a href="stock.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 库存列表 -->
                <h3>库存信息</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>物资编号</th>
                                <th>物资名称</th>
                                <th>所属分类</th>
                                <th>库存数量</th>
                                <th>单位</th>
                                <th>最后交易时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($stocks)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无库存记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($stocks as $stock): ?>
                                    <tr>
                                        <td><?php echo $stock['item_code']; ?></td>
                                        <td><?php echo $stock['item_name']; ?></td>
                                        <td><?php echo $stock['category_name']; ?></td>
                                        <td class="<?php echo $stock['quantity'] < 10 ? 'stock-low' : ''; ?>">
                                            <?php echo $stock['quantity']; ?>
                                        </td>
                                        <td><?php echo $stock['unit']; ?></td>
                                        <td>
                                            <?php echo $stock['last_transaction_time'] ? date('Y-m-d H:i', strtotime($stock['last_transaction_time'])) : '-'; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 库存交易记录 -->
                <h3>最近库存交易记录</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>交易时间</th>
                                <th>物资名称</th>
                                <th>交易类型</th>
                                <th>数量</th>
                                <th>单位</th>
                                <th>供应商/部门</th>
                                <th>操作人</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($transactions)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无交易记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($transactions as $trans): ?>
                                    <tr>
                                        <td><?php echo date('Y-m-d H:i', strtotime($trans['transaction_time'])); ?></td>
                                        <td><?php echo $trans['item_name']; ?></td>
                                        <td class="transaction-type-<?php echo $trans['transaction_type']; ?>">
                                            <?php echo $trans['transaction_type'] == 1 ? '入库' : '出库'; ?>
                                        </td>
                                        <td><?php echo $trans['quantity']; ?></td>
                                        <td><?php echo $trans['unit']; ?></td>
                                        <td>
                                            <?php
                                            if ($trans['transaction_type'] == 1) {
                                                echo $trans['supplier_name'] ?: '-';
                                            } else {
                                                echo $trans['department'] ?: '-';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo $trans['operator_name'] ?: '-'; ?></td>
                                        <td><?php echo $trans['remarks'] ?: '-'; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 显示物资单位
        document.addEventListener('DOMContentLoaded', function() {
            var itemSelect = document.getElementById('item_id');
            var quantityInput = document.getElementById('quantity');
            var unitText = document.getElementById('unit_text');
            var stockWarning = document.getElementById('stock_warning');
            var submitBtn = document.getElementById('submitBtn');

            if (itemSelect) {
                itemSelect.addEventListener('change', function() {
                    var option = this.options[this.selectedIndex];
                    var unit = option.getAttribute('data-unit') || '';
                    unitText.textContent = unit;

                    // 出库时检查库存
                    var form = document.getElementById('outboundForm');
                    if (form) {
                        var stock = parseInt(option.getAttribute('data-stock') || '0');

                        // 更新库存警告逻辑
                        if (quantityInput.value) {
                            checkStockLimit(stock);
                        }
                    }
                });

                // 出库数量验证
                if (quantityInput && document.getElementById('outboundForm')) {
                    quantityInput.addEventListener('input', function() {
                        var option = itemSelect.options[itemSelect.selectedIndex];
                        if (option.value) {
                            var stock = parseInt(option.getAttribute('data-stock') || '0');
                            checkStockLimit(stock);
                        }
                    });
                }

                // 库存限制检查
                function checkStockLimit(stock) {
                    var quantity = parseInt(quantityInput.value || '0');
                    if (quantity > stock) {
                        stockWarning.style.display = 'inline';
                        submitBtn.disabled = true;
                    } else {
                        stockWarning.style.display = 'none';
                        submitBtn.disabled = false;
                    }
                }
            }
        });
    </script>
</body>

</html>