<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory_supplier');

// 记录访问日志
record_log('访问供应商管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加供应商
    if ($_POST['action'] == 'add') {
        $supplier_name = isset($_POST['supplier_name']) ? trim($_POST['supplier_name']) : '';
        $contact_person = isset($_POST['contact_person']) ? trim($_POST['contact_person']) : '';
        $contact_phone = isset($_POST['contact_phone']) ? trim($_POST['contact_phone']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($supplier_name)) {
            $error = '供应商名称不能为空！';
        } else {
            try {
                // 检查是否已存在同名供应商
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM inv_suppliers WHERE supplier_name = ?");
                $stmt->execute([$supplier_name]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '供应商名称已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO inv_suppliers (
                            supplier_name, contact_person, contact_phone, address, status
                        ) VALUES (?, ?, ?, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $supplier_name,
                        $contact_person,
                        $contact_phone,
                        $address,
                        $status
                    ]);

                    if ($result) {
                        record_log("添加供应商：{$supplier_name}");
                        $success = '供应商添加成功！';
                    } else {
                        $error = '供应商添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑供应商
    elseif ($_POST['action'] == 'edit') {
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $supplier_name = isset($_POST['supplier_name']) ? trim($_POST['supplier_name']) : '';
        $contact_person = isset($_POST['contact_person']) ? trim($_POST['contact_person']) : '';
        $contact_phone = isset($_POST['contact_phone']) ? trim($_POST['contact_phone']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($supplier_id <= 0 || empty($supplier_name)) {
            $error = '供应商ID和名称不能为空！';
        } else {
            try {
                // 检查是否已存在同名供应商（排除自身）
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM inv_suppliers WHERE supplier_name = ? AND id != ?");
                $stmt->execute([$supplier_name, $supplier_id]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '供应商名称已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        UPDATE inv_suppliers 
                        SET supplier_name = ?, contact_person = ?, contact_phone = ?, 
                            address = ?, status = ? 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $supplier_name,
                        $contact_person,
                        $contact_phone,
                        $address,
                        $status,
                        $supplier_id
                    ]);

                    if ($result) {
                        record_log("编辑供应商：{$supplier_name}，ID：{$supplier_id}");
                        $success = '供应商信息更新成功！';
                    } else {
                        $error = '供应商信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除供应商
    elseif ($_POST['action'] == 'delete') {
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;

        if ($supplier_id <= 0) {
            $error = '无效的供应商ID！';
        } else {
            try {
                // 检查是否有关联的交易记录
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM inv_transactions WHERE supplier_id = ?");
                $stmt->execute([$supplier_id]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '该供应商有关联的交易记录，无法删除！';
                } else {
                    // 获取供应商信息，用于日志记录
                    $stmt = $pdo->prepare("SELECT supplier_name FROM inv_suppliers WHERE id = ?");
                    $stmt->execute([$supplier_id]);
                    $supplier = $stmt->fetch();

                    if (!$supplier) {
                        $error = '供应商不存在！';
                    } else {
                        $stmt = $pdo->prepare("DELETE FROM inv_suppliers WHERE id = ?");
                        $result = $stmt->execute([$supplier_id]);

                        if ($result) {
                            record_log("删除供应商：{$supplier['supplier_name']}");
                            $success = '供应商删除成功！';
                        } else {
                            $error = '供应商删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取供应商详情
$edit_supplier = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $supplier_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM inv_suppliers WHERE id = ?");
        $stmt->execute([$supplier_id]);
        $edit_supplier = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取供应商详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_supplier_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取所有供应商
try {
    $stmt = $pdo->query("SELECT * FROM inv_suppliers ORDER BY id DESC");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取供应商列表失败：' . $e->getMessage();
    $suppliers = [];
}

// 获取供应商相关交易记录
$supplier_transactions = [];
if ($view_supplier_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT t.*, i.item_name, i.item_code, i.unit, u.username AS operator_name
            FROM inv_transactions t
            JOIN inv_items i ON t.item_id = i.id
            LEFT JOIN sys_users u ON t.operator_id = u.id
            WHERE t.supplier_id = ?
            ORDER BY t.transaction_time DESC
            LIMIT 100
        ");
        $stmt->execute([$view_supplier_id]);
        $supplier_transactions = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取供应商交易记录失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>供应商管理</h2>
            <div class="breadcrumb">
                <a href="index.php">物资管理</a> &gt; 供应商管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_supplier): ?>
                    <a href="supplier.php?show_form=add" class="btn btn-primary">添加供应商</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加供应商表单 -->
                <h3>添加供应商</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="supplier_name">供应商名称：</label>
                            <input type="text" id="supplier_name" name="supplier_name" required>
                        </div>

                        <div class="form-group">
                            <label for="contact_person">联系人：</label>
                            <input type="text" id="contact_person" name="contact_person">
                        </div>

                        <div class="form-group">
                            <label for="contact_phone">联系电话：</label>
                            <input type="text" id="contact_phone" name="contact_phone">
                        </div>

                        <div class="form-group">
                            <label for="address">地址：</label>
                            <input type="text" id="address" name="address">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">启用</option>
                                <option value="0">禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="supplier.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_supplier): ?>
                <!-- 编辑供应商表单 -->
                <h3>编辑供应商</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="supplier_id" value="<?php echo $edit_supplier['id']; ?>">

                        <div class="form-group">
                            <label for="supplier_name">供应商名称：</label>
                            <input type="text" id="supplier_name" name="supplier_name" value="<?php echo htmlspecialchars($edit_supplier['supplier_name']); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="contact_person">联系人：</label>
                            <input type="text" id="contact_person" name="contact_person" value="<?php echo htmlspecialchars($edit_supplier['contact_person']); ?>">
                        </div>

                        <div class="form-group">
                            <label for="contact_phone">联系电话：</label>
                            <input type="text" id="contact_phone" name="contact_phone" value="<?php echo htmlspecialchars($edit_supplier['contact_phone']); ?>">
                        </div>

                        <div class="form-group">
                            <label for="address">地址：</label>
                            <input type="text" id="address" name="address" value="<?php echo htmlspecialchars($edit_supplier['address'] ?? ''); ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_supplier['status'] == 1 ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo $edit_supplier['status'] == 0 ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="supplier.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_supplier): ?>
                <h3>供应商列表</h3>
                <!-- 供应商列表 -->
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>供应商名称</th>
                                <th>联系人</th>
                                <th>联系电话</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($suppliers as $supplier): ?>
                                <tr>
                                    <td><?php echo $supplier['id']; ?></td>
                                    <td><?php echo htmlspecialchars($supplier['supplier_name']); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['contact_person']); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['contact_phone']); ?></td>
                                    <td>
                                        <?php if ($supplier['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="supplier.php?view=<?php echo $supplier['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        <a href="supplier.php?edit=<?php echo $supplier['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此供应商吗？如有关联交易记录将无法删除！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="supplier_id" value="<?php echo $supplier['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    </td>
                                </tr>
                                <?php if ($view_supplier_id == $supplier['id']): ?>
                                    <tr id="supplier-<?php echo $supplier['id']; ?>">
                                        <td colspan="6" class="details-row">
                                            <div class="supplier-details">
                                                <div class="detail-group">
                                                    <h4>基本信息</h4>
                                                    <p><strong>地址：</strong> <?php echo htmlspecialchars($supplier['address'] ?? '-'); ?></p>
                                                </div>

                                                <?php if (!empty($supplier_transactions)): ?>
                                                    <div class="detail-group">
                                                        <h4>最近交易记录</h4>
                                                        <table class="inner-table">
                                                            <thead>
                                                                <tr>
                                                                    <th>日期</th>
                                                                    <th>物资</th>
                                                                    <th>数量</th>
                                                                    <th>类型</th>
                                                                    <th>操作人</th>
                                                                </tr>
                                                            </thead>
                                                            <tbody>
                                                                <?php foreach ($supplier_transactions as $transaction): ?>
                                                                    <tr>
                                                                        <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_time'])); ?></td>
                                                                        <td><?php echo $transaction['item_name']; ?> (<?php echo $transaction['item_code']; ?>)</td>
                                                                        <td><?php echo $transaction['quantity'] . ' ' . $transaction['unit']; ?></td>
                                                                        <td><?php echo $transaction['transaction_type'] == 1 ? '入库' : '出库'; ?></td>
                                                                        <td><?php echo $transaction['operator_name'] ?: '-'; ?></td>
                                                                    </tr>
                                                                <?php endforeach; ?>
                                                            </tbody>
                                                        </table>
                                                    </div>
                                                <?php else: ?>
                                                    <div class="detail-group">
                                                        <p>暂无交易记录</p>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>