<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('ota_manage');

// 记录访问日志
record_log('访问OTA及渠道管理页面');

// 获取所有OTA渠道信息
try {
    $stmt = $pdo->query("
        SELECT * 
        FROM ota_channels 
        ORDER BY id
    ");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取渠道统计数据
try {
    $stmt = $pdo->query("
        SELECT 
            COUNT(*) as total_channels,
            SUM(CASE WHEN status = 1 THEN 1 ELSE 0 END) as active_channels
        FROM ota_channels
    ");
    $channel_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取渠道统计数据失败：' . $e->getMessage();
    $channel_stats = ['total_channels' => 0, 'active_channels' => 0];
}

// 获取房价设置数据
try {
    $stmt = $pdo->query("
        SELECT 
            COUNT(*) as total_rates,
            COUNT(DISTINCT channel_id) as channels_with_rates,
            COUNT(DISTINCT room_type_id) as room_types_with_rates,
            AVG(price) as avg_price
        FROM ota_room_rates
        WHERE date >= CURDATE()
    ");
    $rate_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取房价统计数据失败：' . $e->getMessage();
    $rate_stats = ['total_rates' => 0, 'channels_with_rates' => 0, 'room_types_with_rates' => 0, 'avg_price' => 0];
}

// 获取各渠道房价设置数量
try {
    $stmt = $pdo->query("
        SELECT c.id, c.channel_name, 
               COUNT(r.id) as rate_count,
               AVG(r.price) as avg_price
        FROM ota_channels c
        LEFT JOIN ota_room_rates r ON c.id = r.channel_id AND r.date >= CURDATE()
        GROUP BY c.id
        ORDER BY c.id
    ");
    $channel_rate_stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取渠道房价统计失败：' . $e->getMessage();
    $channel_rate_stats = [];
}

// 获取今日可售库存总数
try {
    $stmt = $pdo->query("
        SELECT SUM(inventory) as total_inventory
        FROM ota_room_rates
        WHERE date = CURDATE() AND status = 1
    ");
    $inventory_stats = $stmt->fetch();
    $total_inventory = $inventory_stats ? intval($inventory_stats['total_inventory']) : 0;
} catch (PDOException $e) {
    $error = '获取库存统计数据失败：' . $e->getMessage();
    $total_inventory = 0;
}

// 计算未设置房价的渠道数
$channels_without_rates = intval($channel_stats['total_channels']) - intval($rate_stats['channels_with_rates']);
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA及渠道管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>渠道总数</h3>
                    <div class="number"><?php echo $channel_stats['total_channels']; ?></div>
                    <div class="desc">活跃渠道：<?php echo $channel_stats['active_channels']; ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>房价设置</h3>
                    <div class="number"><?php echo $rate_stats['total_rates']; ?></div>
                    <div class="desc">未来日期设置的房价数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>可售库存</h3>
                    <div class="number"><?php echo $total_inventory; ?></div>
                    <div class="desc">今日所有渠道可售房间数</div>
                </div>

                <div class="dashboard-card">
                    <h3>平均房价</h3>
                    <div class="number">￥<?php echo number_format($rate_stats['avg_price'], 2); ?></div>
                    <div class="desc">未来日期所有渠道平均价格</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="channel.php" class="function-link">
                    <h3>渠道管理</h3>
                </a>
                <a href="price.php" class="function-link">
                    <h3>价格管理</h3>
                </a>
                <a href="sync.php" class="function-link">
                    <h3>数据同步</h3>
                </a>
                <a href="report.php" class="function-link">
                    <h3>数据分析</h3>
                </a>
            </div>

            <h2>渠道统计数据</h2>
            <div class="system-info">
                <table class="info-table">
                    <tr>
                        <td>渠道总数：</td>
                        <td><?php echo $channel_stats['total_channels']; ?></td>
                    </tr>
                    <tr>
                        <td>已设置房价渠道数：</td>
                        <td><?php echo $rate_stats['channels_with_rates']; ?></td>
                    </tr>
                    <tr>
                        <td>未设置房价渠道数：</td>
                        <td><?php echo $channels_without_rates; ?></td>
                    </tr>
                    <tr>
                        <td>设置房价的房型数：</td>
                        <td><?php echo $rate_stats['room_types_with_rates']; ?></td>
                    </tr>
                    <tr>
                        <td>今日可售库存总数：</td>
                        <td><?php echo $total_inventory; ?></td>
                    </tr>
                    <tr>
                        <td>平均房价：</td>
                        <td>￥<?php echo number_format($rate_stats['avg_price'], 2); ?></td>
                    </tr>
                </table>
            </div>

            <h2>渠道概览</h2>
            <div class="quick-actions">
                <a href="channel.php?show_form=add" class="btn btn-primary">添加渠道</a>
                <a href="price.php?action=batch" class="btn btn-secondary">批量设置房价</a>
                <a href="sync.php?action=sync_inventory" class="btn btn-success">同步库存</a>
            </div>

            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>渠道代码</th>
                            <th>渠道名称</th>
                            <th>佣金比例</th>
                            <th>价格设置数</th>
                            <th>平均房价</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($channels as $channel): ?>
                            <?php
                            $channel_stat = array_filter($channel_rate_stats, function ($item) use ($channel) {
                                return $item['id'] == $channel['id'];
                            });
                            $channel_stat = reset($channel_stat) ?: ['rate_count' => 0, 'avg_price' => 0];
                            ?>
                            <tr>
                                <td><?php echo $channel['id']; ?></td>
                                <td><?php echo $channel['channel_code']; ?></td>
                                <td><?php echo $channel['channel_name']; ?></td>
                                <td><?php echo $channel['commission_rate']; ?>%</td>
                                <td><?php echo $channel_stat['rate_count']; ?></td>
                                <td>￥<?php echo number_format($channel_stat['avg_price'], 2); ?></td>
                                <td>
                                    <?php if ($channel['status'] == 1): ?>
                                        <span class="status-active">启用</span>
                                    <?php else: ?>
                                        <span class="status-inactive">禁用</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="channel.php?edit=<?php echo $channel['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                    <a href="price.php?channel_id=<?php echo $channel['id']; ?>" class="btn btn-sm btn-details">房价</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>