<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('ota_inventory');

// 记录访问日志
record_log('访问OTA库存管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 更新单个库存
    if ($_POST['action'] == 'update') {
        $rate_id = isset($_POST['rate_id']) ? intval($_POST['rate_id']) : 0;
        $inventory = isset($_POST['inventory']) ? intval($_POST['inventory']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($rate_id <= 0) {
            $error = '无效的房价ID！';
        } else {
            try {
                $stmt = $pdo->prepare("
                    UPDATE ota_room_rates 
                    SET inventory = ?, status = ? 
                    WHERE id = ?
                ");
                $result = $stmt->execute([$inventory, $status, $rate_id]);

                if ($result) {
                    // 获取更新后的房价信息，用于日志记录
                    $stmt = $pdo->prepare("
                        SELECT r.*, c.channel_name, t.type_name 
                        FROM ota_room_rates r
                        JOIN ota_channels c ON r.channel_id = c.id
                        JOIN room_types t ON r.room_type_id = t.id
                        WHERE r.id = ?
                    ");
                    $stmt->execute([$rate_id]);
                    $rate = $stmt->fetch();

                    record_log("更新OTA库存：渠道 {$rate['channel_name']}，房型 {$rate['type_name']}，日期 {$rate['date']}，库存 {$inventory}");
                    $success = 'OTA库存更新成功！';
                } else {
                    $error = 'OTA库存更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 批量更新库存
    elseif ($_POST['action'] == 'batch_update') {
        $channel_id = isset($_POST['batch_channel_id']) ? intval($_POST['batch_channel_id']) : 0;
        $room_type_id = isset($_POST['batch_room_type_id']) ? intval($_POST['batch_room_type_id']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $inventory = isset($_POST['batch_inventory']) ? intval($_POST['batch_inventory']) : 0;
        $status = isset($_POST['batch_status']) ? intval($_POST['batch_status']) : 1;

        if ($channel_id <= 0 || $room_type_id <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的批量设置信息！';
        } elseif (strtotime($start_date) > strtotime($end_date)) {
            $error = '开始日期不能大于结束日期！';
        } else {
            try {
                $pdo->beginTransaction();

                // 更新指定日期范围内的库存
                $stmt = $pdo->prepare("
                    UPDATE ota_room_rates 
                    SET inventory = ?, status = ? 
                    WHERE channel_id = ? AND room_type_id = ? AND date BETWEEN ? AND ?
                ");
                $result = $stmt->execute([
                    $inventory,
                    $status,
                    $channel_id,
                    $room_type_id,
                    $start_date,
                    $end_date
                ]);

                // 获取受影响的行数
                $affected_rows = $stmt->rowCount();

                if ($result) {
                    $pdo->commit();
                    record_log("批量更新OTA库存：渠道ID {$channel_id}，房型ID {$room_type_id}，日期 {$start_date} 至 {$end_date}，库存 {$inventory}");
                    $success = "批量更新OTA库存成功！共更新 {$affected_rows} 条记录。";
                } else {
                    $pdo->rollBack();
                    $error = '批量更新OTA库存失败！';
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 同步房态库存到OTA
    elseif ($_POST['action'] == 'sync_from_hotel') {
        $channel_id = isset($_POST['sync_channel_id']) ? intval($_POST['sync_channel_id']) : 0;
        $start_date = isset($_POST['sync_start_date']) ? trim($_POST['sync_start_date']) : '';
        $end_date = isset($_POST['sync_end_date']) ? trim($_POST['sync_end_date']) : '';

        if ($channel_id <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的同步设置信息！';
        } elseif (strtotime($start_date) > strtotime($end_date)) {
            $error = '开始日期不能大于结束日期！';
        } else {
            try {
                $pdo->beginTransaction();

                // 获取日期范围内所有房型的可用房间数（这里是一个示例查询，实际需要根据您的房态表结构调整）
                // 假设我们有一个查询可以获取每种房型在每天的可用房间数
                $sync_count = 0;

                // 模拟同步过程
                $current_date = $start_date;
                while (strtotime($current_date) <= strtotime($end_date)) {
                    // 遍历所有房型
                    $stmt = $pdo->query("SELECT id FROM room_types WHERE status = 1");
                    $room_types = $stmt->fetchAll();

                    foreach ($room_types as $room_type) {
                        $room_type_id = $room_type['id'];

                        // 计算该房型在当天的可用房间数
                        // 这里仅作为示例，实际上需要基于您的房态管理逻辑来获取真实数据
                        $available_rooms = rand(0, 10); // 随机模拟0-10间可用房

                        // 检查是否已有该渠道、房型、日期的记录
                        $stmt = $pdo->prepare("
                            SELECT id FROM ota_room_rates 
                            WHERE channel_id = ? AND room_type_id = ? AND date = ?
                        ");
                        $stmt->execute([$channel_id, $room_type_id, $current_date]);
                        $existing = $stmt->fetch();

                        if ($existing) {
                            // 更新现有记录
                            $stmt = $pdo->prepare("
                                UPDATE ota_room_rates 
                                SET inventory = ? 
                                WHERE id = ?
                            ");
                            $result = $stmt->execute([$available_rooms, $existing['id']]);
                        } else {
                            // 跳过不存在的记录，因为没有价格信息
                            continue;
                        }

                        if ($result) {
                            $sync_count++;
                        }
                    }

                    // 移动到下一天
                    $current_date = date('Y-m-d', strtotime($current_date . ' + 1 day'));
                }

                $pdo->commit();
                record_log("从酒店房态同步库存到OTA：渠道ID {$channel_id}，日期 {$start_date} 至 {$end_date}");
                $success = "库存同步成功！共更新 {$sync_count} 条库存记录。";
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 同步库存到OTA平台
    elseif ($_POST['action'] == 'sync_to_ota') {
        $channel_id = isset($_POST['sync_to_ota_id']) ? intval($_POST['sync_to_ota_id']) : 0;
        $start_date = isset($_POST['sync_to_ota_start']) ? trim($_POST['sync_to_ota_start']) : '';
        $end_date = isset($_POST['sync_to_ota_end']) ? trim($_POST['sync_to_ota_end']) : '';

        if ($channel_id <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的同步设置信息！';
        } elseif (strtotime($start_date) > strtotime($end_date)) {
            $error = '开始日期不能大于结束日期！';
        } else {
            try {
                // 获取OTA渠道信息
                $stmt = $pdo->prepare("SELECT channel_name, channel_code FROM ota_channels WHERE id = ?");
                $stmt->execute([$channel_id]);
                $channel = $stmt->fetch();

                if (!$channel) {
                    $error = '无效的OTA渠道！';
                } else {
                    // 获取需要同步的库存数据
                    $stmt = $pdo->prepare("
                        SELECT r.*, t.type_name 
                        FROM ota_room_rates r
                        JOIN room_types t ON r.room_type_id = t.id
                        WHERE r.channel_id = ? AND r.date BETWEEN ? AND ?
                    ");
                    $stmt->execute([$channel_id, $start_date, $end_date]);
                    $inventory_data = $stmt->fetchAll();

                    // 这里应该有实际的API调用代码来同步库存到OTA平台
                    // 这里只是模拟同步成功，实际项目中需要替换为真实的API调用

                    record_log("同步库存到OTA平台：{$channel['channel_name']}，日期 {$start_date} 至 {$end_date}");
                    $success = "库存同步到OTA平台成功！共同步 " . count($inventory_data) . " 条库存记录。";
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 设置默认查询日期范围
$today = date('Y-m-d');
$default_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : $today;
$default_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d', strtotime('+7 days'));

// 判断是否显示批量更新表单
$show_batch_form = isset($_GET['show_form']) && $_GET['show_form'] == 'batch';

// 判断是否显示同步房态表单
$show_sync_from_hotel_form = isset($_GET['show_form']) && $_GET['show_form'] == 'sync_from_hotel';

// 判断是否显示同步到OTA表单
$show_sync_to_ota_form = isset($_GET['show_form']) && $_GET['show_form'] == 'sync_to_ota';

// 获取所有OTA渠道
try {
    $stmt = $pdo->query("SELECT id, channel_code, channel_name FROM ota_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 获取筛选条件
$filter_channel = isset($_GET['channel_id']) ? intval($_GET['channel_id']) : 0;
$filter_room_type = isset($_GET['room_type_id']) ? intval($_GET['room_type_id']) : 0;
$filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : $default_start_date;
$filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : $default_end_date;

// 构建查询条件
$where_clauses = ["r.date BETWEEN ? AND ?"];
$params = [$filter_start_date, $filter_end_date];

if ($filter_channel > 0) {
    $where_clauses[] = "r.channel_id = ?";
    $params[] = $filter_channel;
}

if ($filter_room_type > 0) {
    $where_clauses[] = "r.room_type_id = ?";
    $params[] = $filter_room_type;
}

$where_sql = implode(" AND ", $where_clauses);

// 获取OTA库存列表
try {
    $stmt = $pdo->prepare("
        SELECT r.*, c.channel_name, t.type_name 
        FROM ota_room_rates r
        JOIN ota_channels c ON r.channel_id = c.id
        JOIN room_types t ON r.room_type_id = t.id
        WHERE {$where_sql}
        ORDER BY r.date, c.id, t.id
    ");
    $stmt->execute($params);
    $inventories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA库存列表失败：' . $e->getMessage();
    $inventories = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>OTA库存管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA库存管理</h2>
            <div class="breadcrumb">
                <a href="index.php">OTA管理</a> &gt; 库存管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_batch_form && !$show_sync_from_hotel_form && !$show_sync_to_ota_form): ?>
                    <a href="inventory.php?show_form=batch" class="btn btn-primary">批量更新库存</a>
                    <a href="inventory.php?show_form=sync_from_hotel" class="btn btn-success">从房态同步</a>
                    <a href="inventory.php?show_form=sync_to_ota" class="btn btn-warning">同步到OTA</a>
                <?php endif; ?>
            </div>

            <?php if ($show_batch_form): ?>
                <!-- 批量更新库存表单 -->
                <h3>批量更新OTA库存</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="batch_update">

                        <div class="form-group">
                            <label for="batch_channel_id">OTA渠道：</label>
                            <select id="batch_channel_id" name="batch_channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="batch_room_type_id">房型：</label>
                            <select id="batch_room_type_id" name="batch_room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>"><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $default_start_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $default_end_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="batch_inventory">可售数量：</label>
                            <input type="number" id="batch_inventory" name="batch_inventory" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="batch_status">状态：</label>
                            <select id="batch_status" name="batch_status">
                                <option value="1">可售</option>
                                <option value="0">停售</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="inventory.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_sync_from_hotel_form): ?>
                <!-- 从房态同步表单 -->
                <h3>从酒店房态同步库存</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="sync_from_hotel">

                        <div class="form-group">
                            <label for="sync_channel_id">OTA渠道：</label>
                            <select id="sync_channel_id" name="sync_channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="sync_start_date">开始日期：</label>
                            <input type="date" id="sync_start_date" name="sync_start_date" value="<?php echo $default_start_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="sync_end_date">结束日期：</label>
                            <input type="date" id="sync_end_date" name="sync_end_date" value="<?php echo $default_end_date; ?>" required>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">开始同步</button>
                            <a href="inventory.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_sync_to_ota_form): ?>
                <!-- 同步到OTA表单 -->
                <h3>同步库存到OTA平台</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="sync_to_ota">

                        <div class="form-group">
                            <label for="sync_to_ota_id">OTA渠道：</label>
                            <select id="sync_to_ota_id" name="sync_to_ota_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="sync_to_ota_start">开始日期：</label>
                            <input type="date" id="sync_to_ota_start" name="sync_to_ota_start" value="<?php echo $default_start_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="sync_to_ota_end">结束日期：</label>
                            <input type="date" id="sync_to_ota_end" name="sync_to_ota_end" value="<?php echo $default_end_date; ?>" required>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">开始同步</button>
                            <a href="inventory.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_batch_form && !$show_sync_from_hotel_form && !$show_sync_to_ota_form): ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="channel_id">OTA渠道：</label>
                                <select id="channel_id" name="channel_id">
                                    <option value="0">所有渠道</option>
                                    <?php foreach ($channels as $channel): ?>
                                        <option value="<?php echo $channel['id']; ?>" <?php echo $filter_channel == $channel['id'] ? 'selected' : ''; ?>><?php echo $channel['channel_name']; ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="room_type_id">房型：</label>
                                <select id="room_type_id" name="room_type_id">
                                    <option value="0">所有房型</option>
                                    <?php foreach ($room_types as $type): ?>
                                        <option value="<?php echo $type['id']; ?>" <?php echo $filter_room_type == $type['id'] ? 'selected' : ''; ?>><?php echo $type['type_name']; ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item">
                                <label for="filter_start_date">开始日期：</label>
                                <input type="date" id="filter_start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="filter_end_date">结束日期：</label>
                                <input type="date" id="filter_end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- OTA库存列表 -->
                <h3>OTA库存列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>渠道</th>
                                <th>房型</th>
                                <th>日期</th>
                                <th>房价(元)</th>
                                <th>可售数量</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($inventories as $inventory): ?>
                                <tr>
                                    <td><?php echo $inventory['id']; ?></td>
                                    <td><?php echo $inventory['channel_name']; ?></td>
                                    <td><?php echo $inventory['type_name']; ?></td>
                                    <td><?php echo $inventory['date']; ?></td>
                                    <td><?php echo number_format($inventory['price'], 2); ?></td>
                                    <td>
                                        <form method="post" action="">
                                            <input type="hidden" name="action" value="update">
                                            <input type="hidden" name="rate_id" value="<?php echo $inventory['id']; ?>">
                                            <input type="number" name="inventory" value="<?php echo $inventory['inventory']; ?>" min="0" style="width: 70px;" onchange="this.form.submit()">
                                        </form>
                                    </td>
                                    <td>
                                        <form method="post" action="">
                                            <input type="hidden" name="action" value="update">
                                            <input type="hidden" name="rate_id" value="<?php echo $inventory['id']; ?>">
                                            <input type="hidden" name="inventory" value="<?php echo $inventory['inventory']; ?>">
                                            <select name="status" onchange="this.form.submit()">
                                                <option value="1" <?php echo $inventory['status'] == 1 ? 'selected' : ''; ?>>可售</option>
                                                <option value="0" <?php echo $inventory['status'] == 0 ? 'selected' : ''; ?>>停售</option>
                                            </select>
                                        </form>
                                    </td>
                                    <td>
                                        <button class="btn btn-sm btn-success inventory-sync-btn" data-id="<?php echo $inventory['id']; ?>" data-channel="<?php echo $inventory['channel_id']; ?>">同步</button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (count($inventories) == 0): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无库存数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 单条库存同步按钮点击事件
        document.addEventListener('DOMContentLoaded', function() {
            const syncButtons = document.querySelectorAll('.inventory-sync-btn');

            syncButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const rateId = this.getAttribute('data-id');
                    const channelId = this.getAttribute('data-channel');

                    // 这里可以发送AJAX请求或表单提交来同步单条库存
                    alert('开始同步ID为 ' + rateId + ' 的库存到OTA平台');

                    // 显示同步中状态
                    this.textContent = '同步中...';
                    this.disabled = true;

                    // 模拟同步完成
                    setTimeout(() => {
                        this.textContent = '已同步';
                        this.classList.remove('btn-success');
                        this.classList.add('btn-secondary');
                    }, 1500);
                });
            });
        });
    </script>
</body>

</html>