<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('ota_price');

// 记录访问日志
record_log('访问OTA价格管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加OTA房价
    if ($_POST['action'] == 'add') {
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $room_type_id = isset($_POST['room_type_id']) ? intval($_POST['room_type_id']) : 0;
        $date = isset($_POST['date']) ? trim($_POST['date']) : '';
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $inventory = isset($_POST['inventory']) ? intval($_POST['inventory']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($channel_id <= 0 || $room_type_id <= 0 || empty($date) || $price <= 0) {
            $error = '请填写完整的房价信息！';
        } else {
            try {
                // 检查是否已存在相同渠道、房型和日期的价格
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM ota_room_rates WHERE channel_id = ? AND room_type_id = ? AND date = ?");
                $stmt->execute([$channel_id, $room_type_id, $date]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '该渠道、房型和日期的价格已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO ota_room_rates (
                            channel_id, room_type_id, date, price, inventory, status
                        ) VALUES (?, ?, ?, ?, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $channel_id,
                        $room_type_id,
                        $date,
                        $price,
                        $inventory,
                        $status
                    ]);

                    if ($result) {
                        record_log("添加OTA房价：渠道ID {$channel_id}，房型ID {$room_type_id}，日期 {$date}");
                        $success = 'OTA房价添加成功！';
                    } else {
                        $error = 'OTA房价添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑OTA房价
    elseif ($_POST['action'] == 'edit') {
        $rate_id = isset($_POST['rate_id']) ? intval($_POST['rate_id']) : 0;
        $channel_id = isset($_POST['channel_id']) ? intval($_POST['channel_id']) : 0;
        $room_type_id = isset($_POST['room_type_id']) ? intval($_POST['room_type_id']) : 0;
        $date = isset($_POST['date']) ? trim($_POST['date']) : '';
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $inventory = isset($_POST['inventory']) ? intval($_POST['inventory']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($rate_id <= 0 || $channel_id <= 0 || $room_type_id <= 0 || empty($date) || $price <= 0) {
            $error = '请填写完整的房价信息！';
        } else {
            try {
                // 检查是否已存在相同渠道、房型和日期的价格（排除当前记录）
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM ota_room_rates WHERE channel_id = ? AND room_type_id = ? AND date = ? AND id != ?");
                $stmt->execute([$channel_id, $room_type_id, $date, $rate_id]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '该渠道、房型和日期的价格已存在！';
                } else {
                    $stmt = $pdo->prepare("
                        UPDATE ota_room_rates 
                        SET channel_id = ?, room_type_id = ?, date = ?, price = ?, inventory = ?, status = ? 
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $channel_id,
                        $room_type_id,
                        $date,
                        $price,
                        $inventory,
                        $status,
                        $rate_id
                    ]);

                    if ($result) {
                        record_log("编辑OTA房价：ID {$rate_id}，渠道ID {$channel_id}，房型ID {$room_type_id}，日期 {$date}");
                        $success = 'OTA房价更新成功！';
                    } else {
                        $error = 'OTA房价更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除OTA房价
    elseif ($_POST['action'] == 'delete') {
        $rate_id = isset($_POST['rate_id']) ? intval($_POST['rate_id']) : 0;

        if ($rate_id <= 0) {
            $error = '无效的房价ID！';
        } else {
            try {
                // 获取房价信息，用于日志记录
                $stmt = $pdo->prepare("
                    SELECT r.*, c.channel_name, t.type_name 
                    FROM ota_room_rates r
                    JOIN ota_channels c ON r.channel_id = c.id
                    JOIN room_types t ON r.room_type_id = t.id
                    WHERE r.id = ?
                ");
                $stmt->execute([$rate_id]);
                $rate = $stmt->fetch();

                if (!$rate) {
                    $error = '房价不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM ota_room_rates WHERE id = ?");
                    $result = $stmt->execute([$rate_id]);

                    if ($result) {
                        record_log("删除OTA房价：ID {$rate_id}，渠道 {$rate['channel_name']}，房型 {$rate['type_name']}，日期 {$rate['date']}");
                        $success = 'OTA房价删除成功！';
                    } else {
                        $error = 'OTA房价删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 批量设置房价
    elseif ($_POST['action'] == 'batch_set') {
        $channel_id = isset($_POST['batch_channel_id']) ? intval($_POST['batch_channel_id']) : 0;
        $room_type_id = isset($_POST['batch_room_type_id']) ? intval($_POST['batch_room_type_id']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $price = isset($_POST['batch_price']) ? floatval($_POST['batch_price']) : 0;
        $inventory = isset($_POST['batch_inventory']) ? intval($_POST['batch_inventory']) : 0;
        $status = isset($_POST['batch_status']) ? intval($_POST['batch_status']) : 1;

        if ($channel_id <= 0 || $room_type_id <= 0 || empty($start_date) || empty($end_date) || $price <= 0) {
            $error = '请填写完整的批量设置信息！';
        } elseif (strtotime($start_date) > strtotime($end_date)) {
            $error = '开始日期不能大于结束日期！';
        } else {
            try {
                $pdo->beginTransaction();

                $current_date = $start_date;
                $update_count = 0;
                $insert_count = 0;

                while (strtotime($current_date) <= strtotime($end_date)) {
                    // 检查是否已存在该日期的价格
                    $stmt = $pdo->prepare("SELECT id FROM ota_room_rates WHERE channel_id = ? AND room_type_id = ? AND date = ?");
                    $stmt->execute([$channel_id, $room_type_id, $current_date]);
                    $existing_rate = $stmt->fetch();

                    if ($existing_rate) {
                        // 更新现有价格
                        $stmt = $pdo->prepare("
                            UPDATE ota_room_rates 
                            SET price = ?, inventory = ?, status = ? 
                            WHERE id = ?
                        ");
                        $result = $stmt->execute([
                            $price,
                            $inventory,
                            $status,
                            $existing_rate['id']
                        ]);
                        if ($result) {
                            $update_count++;
                        }
                    } else {
                        // 插入新价格
                        $stmt = $pdo->prepare("
                            INSERT INTO ota_room_rates (
                                channel_id, room_type_id, date, price, inventory, status
                            ) VALUES (?, ?, ?, ?, ?, ?)
                        ");
                        $result = $stmt->execute([
                            $channel_id,
                            $room_type_id,
                            $current_date,
                            $price,
                            $inventory,
                            $status
                        ]);
                        if ($result) {
                            $insert_count++;
                        }
                    }

                    // 移动到下一天
                    $current_date = date('Y-m-d', strtotime($current_date . ' + 1 day'));
                }

                $pdo->commit();
                record_log("批量设置OTA房价：渠道ID {$channel_id}，房型ID {$room_type_id}，日期 {$start_date} 至 {$end_date}");
                $success = "批量设置OTA房价成功！更新 {$update_count} 条，新增 {$insert_count} 条。";
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 设置默认查询日期范围
$today = date('Y-m-d');
$default_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : $today;
$default_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d', strtotime('+7 days'));

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 判断是否显示批量设置表单
$show_batch_form = isset($_GET['show_form']) && $_GET['show_form'] == 'batch';

// 如果是编辑请求，获取房价详情
$edit_rate = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $rate_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM ota_room_rates WHERE id = ?");
        $stmt->execute([$rate_id]);
        $edit_rate = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取房价详情失败：' . $e->getMessage();
    }
}

// 获取所有OTA渠道
try {
    $stmt = $pdo->query("SELECT id, channel_code, channel_name FROM ota_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 获取OTA房价列表（默认查询一周内的数据）
try {
    $stmt = $pdo->prepare("
        SELECT r.*, c.channel_name, t.type_name 
        FROM ota_room_rates r
        JOIN ota_channels c ON r.channel_id = c.id
        JOIN room_types t ON r.room_type_id = t.id
        WHERE r.date BETWEEN ? AND ?
        ORDER BY r.date, c.id, t.id
    ");
    $stmt->execute([$default_start_date, $default_end_date]);
    $rates = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取OTA房价列表失败：' . $e->getMessage();
    $rates = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>OTA房价管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>OTA房价管理</h2>
            <div class="breadcrumb">
                <a href="index.php">OTA管理</a> &gt; 房价管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_rate && !$show_batch_form): ?>
                    <a href="price.php?show_form=add" class="btn btn-primary">添加房价</a>
                    <a href="price.php?show_form=batch" class="btn btn-success">批量设置</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加OTA房价表单 -->
                <h3>添加OTA房价</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="channel_id">OTA渠道：</label>
                            <select id="channel_id" name="channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>"><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="date">日期：</label>
                            <input type="date" id="date" name="date" required>
                        </div>

                        <div class="form-group">
                            <label for="price">房价：</label>
                            <input type="number" id="price" name="price" step="0.01" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="inventory">可售数量：</label>
                            <input type="number" id="inventory" name="inventory" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1">可售</option>
                                <option value="0">停售</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="price.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_rate): ?>
                <!-- 编辑OTA房价表单 -->
                <h3>编辑OTA房价</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="rate_id" value="<?php echo $edit_rate['id']; ?>">

                        <div class="form-group">
                            <label for="channel_id">OTA渠道：</label>
                            <select id="channel_id" name="channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>" <?php echo $edit_rate['channel_id'] == $channel['id'] ? 'selected' : ''; ?>><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo $edit_rate['room_type_id'] == $type['id'] ? 'selected' : ''; ?>><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="date">日期：</label>
                            <input type="date" id="date" name="date" value="<?php echo $edit_rate['date']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="price">房价：</label>
                            <input type="number" id="price" name="price" step="0.01" min="0" value="<?php echo $edit_rate['price']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="inventory">可售数量：</label>
                            <input type="number" id="inventory" name="inventory" min="0" value="<?php echo $edit_rate['inventory']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo $edit_rate['status'] == 1 ? 'selected' : ''; ?>>可售</option>
                                <option value="0" <?php echo $edit_rate['status'] == 0 ? 'selected' : ''; ?>>停售</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="price.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_batch_form): ?>
                <!-- 批量设置房价表单 -->
                <h3>批量设置OTA房价</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="batch_set">

                        <div class="form-group">
                            <label for="batch_channel_id">OTA渠道：</label>
                            <select id="batch_channel_id" name="batch_channel_id" required>
                                <option value="">请选择OTA渠道</option>
                                <?php foreach ($channels as $channel): ?>
                                    <option value="<?php echo $channel['id']; ?>"><?php echo $channel['channel_name']; ?> (<?php echo $channel['channel_code']; ?>)</option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="batch_room_type_id">房型：</label>
                            <select id="batch_room_type_id" name="batch_room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>"><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $default_start_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $default_end_date; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="batch_price">房价：</label>
                            <input type="number" id="batch_price" name="batch_price" step="0.01" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="batch_inventory">可售数量：</label>
                            <input type="number" id="batch_inventory" name="batch_inventory" min="0" required>
                        </div>

                        <div class="form-group">
                            <label for="batch_status">状态：</label>
                            <select id="batch_status" name="batch_status">
                                <option value="1">可售</option>
                                <option value="0">停售</option>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="price.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_rate && !$show_batch_form): ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="filter_start_date">开始日期：</label>
                                <input type="date" id="filter_start_date" name="start_date" value="<?php echo $default_start_date; ?>">
                            </div>
                            <div class="filter-item">
                                <label for="filter_end_date">结束日期：</label>
                                <input type="date" id="filter_end_date" name="end_date" value="<?php echo $default_end_date; ?>">
                            </div>
                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- OTA房价列表 -->
                <h3>OTA房价列表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>渠道</th>
                                <th>房型</th>
                                <th>日期</th>
                                <th>房价(元)</th>
                                <th>可售数量</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($rates as $rate): ?>
                                <tr>
                                    <td><?php echo $rate['id']; ?></td>
                                    <td><?php echo $rate['channel_name']; ?></td>
                                    <td><?php echo $rate['type_name']; ?></td>
                                    <td><?php echo $rate['date']; ?></td>
                                    <td><?php echo number_format($rate['price'], 2); ?></td>
                                    <td><?php echo $rate['inventory']; ?></td>
                                    <td>
                                        <?php if ($rate['status'] == 1): ?>
                                            <span class="status-active">可售</span>
                                        <?php else: ?>
                                            <span class="status-inactive">停售</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="price.php?edit=<?php echo $rate['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此房价吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="rate_id" value="<?php echo $rate['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (count($rates) == 0): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无房价数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>