<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问房态管理页面');

// 处理房间状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'update_status') {
    $room_id = isset($_POST['room_id']) ? intval($_POST['room_id']) : 0;
    $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;
    $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

    if ($room_id <= 0 || $new_status <= 0 || $new_status > 6) {
        $error = '无效的房间ID或状态值！';
    } else {
        try {
            // 获取房间当前状态和房间号
            $stmt = $pdo->prepare("SELECT room_number, status FROM room_info WHERE id = ?");
            $stmt->execute([$room_id]);
            $room = $stmt->fetch();

            if (!$room) {
                $error = '房间不存在！';
            } else {
                $old_status = $room['status'];

                // 更新房间状态
                $stmt = $pdo->prepare("UPDATE room_info SET status = ? WHERE id = ?");
                $result = $stmt->execute([$new_status, $room_id]);

                if ($result) {
                    // 记录状态变更日志
                    $user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                    $username = isset($_SESSION['username']) ? $_SESSION['username'] : null;

                    $status_texts = [
                        1 => '空闲',
                        2 => '已预订',
                        3 => '已入住',
                        4 => '清洁中',
                        5 => '维修中',
                        6 => '停用'
                    ];

                    $log_content = "房间{$room['room_number']}状态从【{$status_texts[$old_status]}】变更为【{$status_texts[$new_status]}】";
                    if (!empty($remarks)) {
                        $log_content .= "，备注：{$remarks}";
                    }

                    record_log($log_content);

                    // 如果状态变为清洁中，自动创建清洁任务
                    if ($new_status == 4) {
                        $stmt = $pdo->prepare("
                            INSERT INTO room_cleaning (room_id, clean_date, status, remarks)
                            VALUES (?, CURDATE(), 1, ?)
                        ");
                        $stmt->execute([$room_id, "房态变更自动生成的清洁任务" . ($remarks ? "，备注：{$remarks}" : "")]);
                    }

                    // 如果状态变为维修中，自动创建维修任务（如果没有未完成的任务）
                    if ($new_status == 5) {
                        $stmt = $pdo->prepare("
                            SELECT COUNT(*) as count FROM room_maintenance 
                            WHERE room_id = ? AND status IN (1, 2)
                        ");
                        $stmt->execute([$room_id]);
                        $maintenance_count = $stmt->fetch()['count'];

                        if ($maintenance_count == 0) {
                            $stmt = $pdo->prepare("
                                INSERT INTO room_maintenance (
                                    room_id, issue_type, issue_desc, status, reporter_id, 
                                    maintainer_id, report_time
                                ) VALUES (?, ?, ?, 1, ?, NULL, NOW())
                            ");
                            $stmt->execute([
                                $room_id,
                                '其他',
                                "房态变更自动生成的维修任务" . ($remarks ? "，备注：{$remarks}" : ""),
                                $user_id
                            ]);
                        }
                    }

                    $success = '房间状态更新成功！';
                } else {
                    $error = '房间状态更新失败！';
                }
            }
        } catch (PDOException $e) {
            $error = '系统错误：' . $e->getMessage();
        }
    }
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name FROM room_types WHERE status = 1");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $room_types = [];
}

// 获取所有房间及其房型信息
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
$filter_floor = isset($_GET['floor']) ? trim($_GET['floor']) : '';

try {
    $sql = "
        SELECT r.*, t.type_name 
        FROM room_info r
        JOIN room_types t ON r.room_type_id = t.id
        WHERE 1=1
    ";
    $params = [];

    if ($filter_type > 0) {
        $sql .= " AND r.room_type_id = ?";
        $params[] = $filter_type;
    }

    if ($filter_status > 0) {
        $sql .= " AND r.status = ?";
        $params[] = $filter_status;
    }

    if ($filter_floor != '') {
        $sql .= " AND r.floor = ?";
        $params[] = $filter_floor;
    }

    $sql .= " ORDER BY r.floor, r.room_number";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $rooms = $stmt->fetchAll();

    // 获取所有楼层选项
    $stmt = $pdo->query("SELECT DISTINCT floor FROM room_info ORDER BY floor");
    $floors = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $error = '获取房间列表失败：' . $e->getMessage();
    $rooms = [];
    $floors = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>房态管理</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .room-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
            gap: 15px;
            margin-top: 20px;
        }

        .room-card {
            border: 1px solid #ddd;
            border-radius: 4px;
            padding: 15px;
            background-color: #fff;
        }

        .room-status-1 {
            border-left: 5px solid #28a745;
        }

        /* 空闲 */
        .room-status-2 {
            border-left: 5px solid #ffc107;
        }

        /* 已预订 */
        .room-status-3 {
            border-left: 5px solid #dc3545;
        }

        /* 已入住 */
        .room-status-4 {
            border-left: 5px solid #17a2b8;
        }

        /* 清洁中 */
        .room-status-5 {
            border-left: 5px solid #6c757d;
        }

        /* 维修中 */
        .room-status-6 {
            border-left: 5px solid #343a40;
        }

        /* 停用 */

        .room-card h3 {
            margin-top: 0;
            color: #333;
            font-size: 18px;
        }

        .room-card .type {
            color: #666;
            font-size: 14px;
            margin-bottom: 10px;
        }

        .room-card .status {
            margin-top: 10px;
            padding: 5px 0;
            font-weight: bold;
        }

        .floor-section {
            margin-bottom: 30px;
        }

        .floor-section h2 {
            margin-top: 0;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
            font-size: 20px;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>房态管理</h2>
            <div class="breadcrumb">
               <a href="index.php">客房管理</a> &gt; 房态管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="type">房型：</label>
                            <select id="type" name="type">
                                <option value="0">全部房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo $filter_type == $type['id'] ? 'selected' : ''; ?>>
                                        <?php echo $type['type_name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="0">全部状态</option>
                                <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>空闲</option>
                                <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已预订</option>
                                <option value="3" <?php echo $filter_status == 3 ? 'selected' : ''; ?>>已入住</option>
                                <option value="4" <?php echo $filter_status == 4 ? 'selected' : ''; ?>>清洁中</option>
                                <option value="5" <?php echo $filter_status == 5 ? 'selected' : ''; ?>>维修中</option>
                                <option value="6" <?php echo $filter_status == 6 ? 'selected' : ''; ?>>停用</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="floor">楼层：</label>
                            <select id="floor" name="floor">
                                <option value="">全部楼层</option>
                                <?php foreach ($floors as $floor): ?>
                                    <option value="<?php echo $floor; ?>" <?php echo $filter_floor == $floor ? 'selected' : ''; ?>>
                                        <?php echo $floor; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="status.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 房态图例 -->
            <div class="system-info">
                <h3>房态图例</h3>
                <div style="display: flex; flex-wrap: wrap; gap: 15px; margin-top: 10px;">
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #28a745; margin-right: 5px;"></div>
                        <span>空闲</span>
                    </div>
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #ffc107; margin-right: 5px;"></div>
                        <span>已预订</span>
                    </div>
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #dc3545; margin-right: 5px;"></div>
                        <span>已入住</span>
                    </div>
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #17a2b8; margin-right: 5px;"></div>
                        <span>清洁中</span>
                    </div>
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #6c757d; margin-right: 5px;"></div>
                        <span>维修中</span>
                    </div>
                    <div style="display: flex; align-items: center;">
                        <div style="width: 20px; height: 20px; background-color: #343a40; margin-right: 5px;"></div>
                        <span>停用</span>
                    </div>
                </div>
            </div>

            <!-- 房间列表，按楼层分组 -->
            <?php
            $current_floor = '';
            foreach ($rooms as $room):
                if ($room['floor'] != $current_floor):
                    if ($current_floor != '') echo '</div></div>';
                    $current_floor = $room['floor'];
            ?>
                    <div class="floor-section">
                        <h2><?php echo $room['floor']; ?>楼</h2>
                        <div class="room-grid">
                        <?php endif; ?>
                        <div class="room-card room-status-<?php echo $room['status']; ?>">
                            <h3><?php echo $room['room_number']; ?></h3>
                            <div class="type"><?php echo $room['type_name']; ?></div>
                            <div>
                                <?php if ($room['is_smoking']): ?>
                                    <span class="badge">吸烟房</span>
                                <?php else: ?>
                                    <span class="badge">非吸烟房</span>
                                <?php endif; ?>
                            </div>
                            <div class="status">
                                <?php
                                switch ($room['status']) {
                                    case 1:
                                        echo '<span style="color: #28a745;">空闲</span>';
                                        break;
                                    case 2:
                                        echo '<span style="color: #ffc107;">已预订</span>';
                                        break;
                                    case 3:
                                        echo '<span style="color: #dc3545;">已入住</span>';
                                        break;
                                    case 4:
                                        echo '<span style="color: #17a2b8;">清洁中</span>';
                                        break;
                                    case 5:
                                        echo '<span style="color: #6c757d;">维修中</span>';
                                        break;
                                    case 6:
                                        echo '<span style="color: #343a40;">停用</span>';
                                        break;
                                    default:
                                        echo '<span>未知</span>';
                                }
                                ?>
                            </div>
                            <!-- 状态更新按钮 -->
                            <button onclick="showStatusForm(<?php echo $room['id']; ?>, '<?php echo $room['room_number']; ?>', <?php echo $room['status']; ?>)" class="btn btn-sm btn-edit" style="margin-top: 10px;">
                                更新状态
                            </button>

                            <?php if (!empty($room['remarks'])): ?>
                                <div style="margin-top: 10px; font-size: 13px; color: #666;">
                                    <strong>备注：</strong> <?php echo $room['remarks']; ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    <?php endforeach; ?>
                    <?php if ($current_floor != ''): ?>
                        </div>
                    </div>
                <?php endif; ?>
        </div>
    </div>

    <!-- 状态更新模态框 -->
    <div id="statusModal" style="display: none; position: fixed; z-index: 1000; left: 0; top: 0; width: 100%; height: 100%; overflow: auto; background-color: rgba(0,0,0,0.4);">
        <div style="background-color: white; margin: 10% auto; padding: 20px; border-radius: 5px; width: 50%; max-width: 500px;">
            <h3>更新房间状态</h3>
            <form id="statusForm" method="post" action="">
                <input type="hidden" name="action" value="update_status">
                <input type="hidden" id="room_id" name="room_id" value="">

                <div class="form-group">
                    <label for="room_number">房间号：</label>
                    <input type="text" id="room_number" readonly style="background-color: #f8f9fa;">
                </div>

                <div class="form-group">
                    <label for="current_status">当前状态：</label>
                    <input type="text" id="current_status" readonly style="background-color: #f8f9fa;">
                </div>

                <div class="form-group">
                    <label for="new_status">新状态：</label>
                    <select id="new_status" name="new_status" required>
                        <option value="1">空闲</option>
                        <option value="2">已预订</option>
                        <option value="3">已入住</option>
                        <option value="4">清洁中</option>
                        <option value="5">维修中</option>
                        <option value="6">停用</option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="remarks">备注：</label>
                    <textarea id="remarks" name="remarks" rows="3"></textarea>
                </div>

                <div class="form-buttons">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <button type="button" onclick="closeStatusModal()" class="btn btn-secondary">取消</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        function showStatusForm(roomId, roomNumber, currentStatus) {
            document.getElementById('room_id').value = roomId;
            document.getElementById('room_number').value = roomNumber;

            let statusText = '';
            switch (currentStatus) {
                case 1:
                    statusText = '空闲';
                    break;
                case 2:
                    statusText = '已预订';
                    break;
                case 3:
                    statusText = '已入住';
                    break;
                case 4:
                    statusText = '清洁中';
                    break;
                case 5:
                    statusText = '维修中';
                    break;
                case 6:
                    statusText = '停用';
                    break;
                default:
                    statusText = '未知';
            }

            document.getElementById('current_status').value = statusText;
            document.getElementById('new_status').value = currentStatus;
            document.getElementById('statusModal').style.display = 'block';
        }

        function closeStatusModal() {
            document.getElementById('statusModal').style.display = 'none';
        }

        // 点击模态框外部关闭
        window.onclick = function(event) {
            if (event.target == document.getElementById('statusModal')) {
                closeStatusModal();
            }
        }
    </script>
</body>

</html>