<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('stat_view');

// 记录访问日志
record_log('访问房间利用率分析页面');

// 获取当前日期和时间范围
$today = date('Y-m-d');
$current_month = date('m');
$current_year = date('Y');
$yesterday = date('Y-m-d', strtotime('-1 day'));

// 获取筛选条件
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'custom';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '2023-05-30';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '2023-06-02';
$room_type_id = isset($_GET['room_type_id']) ? intval($_GET['room_type_id']) : 0;

// 根据日期范围设置默认值
if ($date_range == 'week') {
    $start_date = date('Y-m-d', strtotime('-6 days'));
    $end_date = $today;
} elseif ($date_range == 'month') {
    $start_date = date('Y-m-01');
    $end_date = date('Y-m-d', strtotime('last day of this month'));
} elseif ($date_range == 'year') {
    $start_date = date('Y-01-01');
    $end_date = date('Y-12-31');
} elseif ($date_range == 'last_month') {
    $start_date = date('Y-m-01', strtotime('first day of last month'));
    $end_date = date('Y-m-d', strtotime('last day of last month'));
}

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 计算统计数据
$total_rooms = 0;
$total_usage_days = 0;
$room_stats = [];

try {
    // 获取房型总数量
    if ($room_type_id > 0) {
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM room_info WHERE room_type_id = ? AND status = 1");
        $stmt->execute([$room_type_id]);
    } else {
        $stmt = $pdo->query("SELECT COUNT(*) FROM room_info WHERE status = 1");
    }
    $total_rooms = $stmt->fetchColumn();

    // 获取日期范围内的总天数
    $date_diff = strtotime($end_date) - strtotime($start_date);
    $days_diff = round($date_diff / (60 * 60 * 24)) + 1;
    $total_room_days = $total_rooms * $days_diff; // 总房间天数

    // 获取每个房型的数据
    $stmt = $pdo->prepare("
        SELECT rt.id, rt.type_name, COUNT(ri.id) as room_count
        FROM room_types rt
        LEFT JOIN room_info ri ON rt.id = ri.room_type_id AND ri.status = 1
        WHERE rt.status = 1 " . ($room_type_id > 0 ? "AND rt.id = ?" : "") . "
        GROUP BY rt.id, rt.type_name
        ORDER BY rt.id
    ");

    if ($room_type_id > 0) {
        $stmt->execute([$room_type_id]);
    } else {
        $stmt->execute();
    }
    $room_stats = $stmt->fetchAll();

    // 获取每个房型的入住天数
    foreach ($room_stats as &$room_stat) {
        $stmt = $pdo->prepare("
            SELECT COUNT(*) as usage_days
            FROM checkin_orders co
            JOIN room_info ri ON co.room_id = ri.id
            WHERE ri.room_type_id = ?
            AND co.status IN (1, 2) -- 在住或已离店
            AND (
                (DATE(co.checkin_time) BETWEEN ? AND ?) OR 
                (DATE(co.checkout_time) BETWEEN ? AND ?) OR
                (DATE(co.checkin_time) <= ? AND DATE(co.checkout_time) >= ?)
            )
        ");
        $stmt->execute([
            $room_stat['id'],
            $start_date,
            $end_date,
            $start_date,
            $end_date,
            $start_date,
            $end_date
        ]);
        $usage_result = $stmt->fetch();
        $room_stat['usage_days'] = $usage_result['usage_days'];

        // 计算房型利用率
        $room_stat['total_days'] = $room_stat['room_count'] * $days_diff;
        $room_stat['usage_rate'] = $room_stat['total_days'] > 0 ?
            round(($room_stat['usage_days'] / $room_stat['total_days']) * 100, 2) : 0;

        $total_usage_days += $room_stat['usage_days'];
    }

    // 计算总体利用率
    $total_usage_rate = $total_room_days > 0 ?
        round(($total_usage_days / $total_room_days) * 100, 2) : 0;
} catch (PDOException $e) {
    $error = '获取房型使用率数据失败：' . $e->getMessage();
    $room_stats = [];
    $total_usage_rate = 0;
}

// 获取每日房型使用情况
$daily_stats = [];
try {
    // 生成日期范围内的所有日期
    $current_date = $start_date;
    while (strtotime($current_date) <= strtotime($end_date)) {
        $daily_stats[$current_date] = [
            'date' => $current_date,
            'total_rooms' => $total_rooms,
            'occupied_rooms' => 0,
            'usage_rate' => 0,
            'room_types' => []
        ];
        $current_date = date('Y-m-d', strtotime($current_date . ' + 1 day'));
    }

    // 获取每日各房型的入住情况
    $sql = "
        SELECT 
            DATE(GREATEST(co.checkin_time, ?)) as stat_date,
            ri.room_type_id,
            rt.type_name,
            COUNT(DISTINCT co.room_id) as occupied_count
        FROM checkin_orders co
        JOIN room_info ri ON co.room_id = ri.id
        JOIN room_types rt ON ri.room_type_id = rt.id
        WHERE co.status IN (1, 2) -- 在住或已离店
        AND (
            (DATE(co.checkin_time) <= ? AND DATE(co.checkout_time) >= ?) OR
            (DATE(co.checkin_time) BETWEEN ? AND ?) OR
            (DATE(co.checkout_time) BETWEEN ? AND ?)
        )
        " . ($room_type_id > 0 ? "AND ri.room_type_id = ?" : "") . "
        GROUP BY stat_date, ri.room_type_id, rt.type_name
        ORDER BY stat_date, ri.room_type_id
    ";

    $params = [
        $start_date,
        $end_date,
        $start_date,
        $start_date,
        $end_date,
        $start_date,
        $end_date
    ];

    if ($room_type_id > 0) {
        $params[] = $room_type_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $daily_room_stats = $stmt->fetchAll();

    // 初始化各房型的房间数量
    foreach ($room_stats as $room_stat) {
        foreach ($daily_stats as &$day) {
            $day['room_types'][$room_stat['id']] = [
                'id' => $room_stat['id'],
                'name' => $room_stat['type_name'],
                'total' => $room_stat['room_count'],
                'occupied' => 0,
                'usage_rate' => 0
            ];
        }
    }

    // 填充每日使用数据
    foreach ($daily_room_stats as $stat) {
        if (isset($daily_stats[$stat['stat_date']])) {
            if (isset($daily_stats[$stat['stat_date']]['room_types'][$stat['room_type_id']])) {
                $daily_stats[$stat['stat_date']]['room_types'][$stat['room_type_id']]['occupied'] = $stat['occupied_count'];

                // 计算该房型当日使用率
                $total = $daily_stats[$stat['stat_date']]['room_types'][$stat['room_type_id']]['total'];
                if ($total > 0) {
                    $daily_stats[$stat['stat_date']]['room_types'][$stat['room_type_id']]['usage_rate'] =
                        round(($stat['occupied_count'] / $total) * 100, 2);
                }

                // 累加当日总占用数
                $daily_stats[$stat['stat_date']]['occupied_rooms'] += $stat['occupied_count'];
            }
        }
    }

    // 计算每日总使用率
    foreach ($daily_stats as &$day) {
        if ($day['total_rooms'] > 0) {
            $day['usage_rate'] = round(($day['occupied_rooms'] / $day['total_rooms']) * 100, 2);
        }
    }
} catch (PDOException $e) {
    $error = '获取每日房型使用数据失败：' . $e->getMessage();
    $daily_stats = [];
}

// 计算每个房型的收入贡献
$revenue_stats = [];
try {
    $stmt = $pdo->prepare("
        SELECT 
            rt.id,
            rt.type_name,
            COUNT(co.id) as order_count,
            SUM(co.total_amount) as total_revenue
        FROM room_types rt
        LEFT JOIN room_info ri ON rt.id = ri.room_type_id
        LEFT JOIN checkin_orders co ON ri.id = co.room_id AND co.status = 2 -- 已离店
        WHERE rt.status = 1 
        " . ($room_type_id > 0 ? "AND rt.id = ? " : "") . "
        AND (co.id IS NULL OR DATE(co.checkout_time) BETWEEN ? AND ?)
        GROUP BY rt.id, rt.type_name
        ORDER BY total_revenue DESC
    ");

    if ($room_type_id > 0) {
        $stmt->execute([$room_type_id, $start_date, $end_date]);
    } else {
        $stmt->execute([$start_date, $end_date]);
    }
    $revenue_stats = $stmt->fetchAll();

    // 计算总收入
    $total_revenue = 0;
    $total_orders = 0;
    foreach ($revenue_stats as &$stat) {
        $total_revenue += $stat['total_revenue'] ?: 0;
        $total_orders += $stat['order_count'] ?: 0;

        // 计算平均订单金额
        $stat['avg_order_amount'] = $stat['order_count'] > 0 ?
            round($stat['total_revenue'] / $stat['order_count'], 2) : 0;
    }

    // 计算收入占比
    foreach ($revenue_stats as &$stat) {
        $stat['revenue_percentage'] = $total_revenue > 0 ?
            round(($stat['total_revenue'] / $total_revenue) * 100, 2) : 0;
    }
} catch (PDOException $e) {
    $error = '获取房型收入数据失败：' . $e->getMessage();
    $revenue_stats = [];
    $total_revenue = 0;
    $total_orders = 0;
}

// 查找使用率最高和最低的房型
$highest_usage_rate = 0;
$highest_usage_room = null;
$lowest_usage_rate = 100;
$lowest_usage_room = null;

foreach ($room_stats as $stat) {
    if ($stat['usage_rate'] > $highest_usage_rate) {
        $highest_usage_rate = $stat['usage_rate'];
        $highest_usage_room = $stat;
    }

    if ($stat['usage_rate'] < $lowest_usage_rate && $stat['room_count'] > 0) {
        $lowest_usage_rate = $stat['usage_rate'];
        $lowest_usage_room = $stat;
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>房间利用率分析</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
            color: #4CAF50;
        }

        .chart-container {
            width: 100%;
            margin-bottom: 20px;
            overflow-x: auto;
        }

        .status-high {
            color: #28a745;
            font-weight: bold;
        }

        .status-medium {
            color: #fd7e14;
        }

        .status-low {
            color: #dc3545;
        }

        .progress-bar {
            height: 20px;
            background-color: #e9ecef;
            border-radius: 3px;
            margin-top: 5px;
            overflow: hidden;
        }

        .progress-bar-fill {
            height: 100%;
            background-color: #4CAF50;
            text-align: center;
            line-height: 20px;
            color: white;
            transition: width 0.5s;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>房间利用率分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 房间利用率分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围：</label>
                            <select id="date_range" name="date_range" onchange="updateDateRange()">
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="last_month" <?php echo $date_range == 'last_month' ? 'selected' : ''; ?>>上月</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>本年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item" id="custom_date" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item" id="custom_date_end" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="room_type_id">房型：</label>
                            <select id="room_type_id" name="room_type_id">
                                <option value="0">全部房型</option>
                                <?php foreach ($room_types as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo $room_type_id == $type['id'] ? 'selected' : ''; ?>><?php echo $type['type_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">分析</button>
                            <a href="room.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 利用率概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">总体利用率</span>
                    <span class="summary-value"><?php echo $total_usage_rate; ?>%</span>
                    <span>日期范围：<?php echo $start_date; ?> 至 <?php echo $end_date; ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">最高利用率房型</span>
                    <span class="summary-value">
                        <?php echo $highest_usage_room ? $highest_usage_room['type_name'] . ' (' . $highest_usage_rate . '%)' : 'N/A'; ?>
                    </span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">最低利用率房型</span>
                    <span class="summary-value">
                        <?php echo $lowest_usage_room ? $lowest_usage_room['type_name'] . ' (' . $lowest_usage_rate . '%)' : 'N/A'; ?>
                    </span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">总收入</span>
                    <span class="summary-value">￥<?php echo number_format($total_revenue, 2); ?></span>
                    <span>订单数：<?php echo $total_orders; ?></span>
                </div>
            </div>

            <!-- 各房型利用率统计 -->
            <h3>各房型利用率统计</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型</th>
                            <th>房间数量</th>
                            <th>使用天数</th>
                            <th>总可用天数</th>
                            <th>利用率</th>
                            <th>利用率图表</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($room_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['type_name']; ?></td>
                                <td><?php echo $stat['room_count']; ?></td>
                                <td><?php echo $stat['usage_days']; ?></td>
                                <td><?php echo $stat['total_days']; ?></td>
                                <td class="<?php
                                            if ($stat['usage_rate'] >= 80) echo 'status-high';
                                            elseif ($stat['usage_rate'] >= 60) echo 'status-medium';
                                            else echo 'status-low';
                                            ?>">
                                    <?php echo $stat['usage_rate']; ?>%
                                </td>
                                <td>
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['usage_rate']; ?>%;">
                                            <?php echo $stat['usage_rate']; ?>%
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($room_stats) == 0): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无房型数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 每日房型利用率 -->
            <h3>每日房型利用率</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <th>总房间数</th>
                            <th>已使用</th>
                            <th>利用率</th>
                            <?php if ($room_type_id == 0): ?>
                                <th>房型详情</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($daily_stats as $day): ?>
                            <tr>
                                <td><?php echo $day['date']; ?></td>
                                <td><?php echo $day['total_rooms']; ?></td>
                                <td><?php echo $day['occupied_rooms']; ?></td>
                                <td class="<?php
                                            if ($day['usage_rate'] >= 80) echo 'status-high';
                                            elseif ($day['usage_rate'] >= 60) echo 'status-medium';
                                            else echo 'status-low';
                                            ?>">
                                    <?php echo $day['usage_rate']; ?>%
                                </td>
                                <?php if ($room_type_id == 0): ?>
                                    <td>
                                        <button type="button" class="btn btn-sm btn-details" onclick="toggleRoomDetails('<?php echo $day['date']; ?>')">查看详情</button>
                                    </td>
                                <?php endif; ?>
                            </tr>
                            <?php if ($room_type_id == 0): ?>
                                <tr id="room-details-<?php echo $day['date']; ?>" style="display: none;">
                                    <td colspan="5">
                                        <table class="data-table" style="margin: 0;">
                                            <thead>
                                                <tr>
                                                    <th>房型</th>
                                                    <th>房间数</th>
                                                    <th>已使用</th>
                                                    <th>利用率</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($day['room_types'] as $room_type): ?>
                                                    <tr>
                                                        <td><?php echo $room_type['name']; ?></td>
                                                        <td><?php echo $room_type['total']; ?></td>
                                                        <td><?php echo $room_type['occupied']; ?></td>
                                                        <td class="<?php
                                                                    if ($room_type['usage_rate'] >= 80) echo 'status-high';
                                                                    elseif ($room_type['usage_rate'] >= 60) echo 'status-medium';
                                                                    else echo 'status-low';
                                                                    ?>">
                                                            <?php echo $room_type['usage_rate']; ?>%
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                        <?php if (count($daily_stats) == 0): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无每日利用率数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 收入贡献分析 -->
            <h3>房型收入贡献分析</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型</th>
                            <th>订单数</th>
                            <th>总收入(元)</th>
                            <th>收入占比</th>
                            <th>平均订单金额(元)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($revenue_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['type_name']; ?></td>
                                <td><?php echo $stat['order_count'] ?: 0; ?></td>
                                <td><?php echo number_format($stat['total_revenue'] ?: 0, 2); ?></td>
                                <td>
                                    <?php echo $stat['revenue_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['revenue_percentage']; ?>%;">
                                            <?php echo $stat['revenue_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo number_format($stat['avg_order_amount'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($revenue_stats) == 0): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无收入数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <script>
        function updateDateRange() {
            var dateRange = document.getElementById('date_range').value;
            var customDateDiv = document.getElementById('custom_date');
            var customDateEndDiv = document.getElementById('custom_date_end');

            if (dateRange === 'custom') {
                customDateDiv.style.display = '';
                customDateEndDiv.style.display = '';
            } else {
                customDateDiv.style.display = 'none';
                customDateEndDiv.style.display = 'none';
            }
        }

        function toggleRoomDetails(date) {
            var detailsRow = document.getElementById('room-details-' + date);
            if (detailsRow.style.display === 'none') {
                detailsRow.style.display = 'table-row';
            } else {
                detailsRow.style.display = 'none';
            }
        }
    </script>
</body>

</html>